




--Title: Creating GSS-HLFS-MSD wellbeing-benefit table 
--Author: Chris K. Deak
--Date created: 24 May, 2022

--Last updated: 2 February, 2023
--Last updated by: Chris
--Changes made: 
			-- Changed names: 
			-- ben_30 is now called main_ben_30 and msd_ben_30 
			-- ben_12 is now called main_ben_12 and msd_ben_12 
			-- ben_01 is now called main_ben_01 and msd_ben_01 




-- Description: 
-- This is a series of SQL queries: 
--1. selects wellbeing measures from six waves of GSS and from four quarters of the wellbeing supplement of the HLFS 2020
--2. unifies the variable names and value codes for the wellbeing measures across all waves and tables (NOTE: not all variables were unified because heavy skewness occured across years)
--3. unites all the tables with the unified variable names and value codes
--4. joins the united tables with MSD benefit data*
--5. saves the created tables to Sandpit
--* for benefit data we use the first-tier and the second-tier tables and only select people who received benefit in the last 36 months up to the wellbeing survey time 

-- Domains and measures:
-- Demographics:

-- Subjective wellbeing: SW_Identity			/ Ability to express identity
-- Subjective wellbeing: SW_LifeSat				/ General life satisfaction
-- Subjective wellbeing: SW_FamWell				/ Family wellbeing
-- Health: HLT_GenHlth							/ General health 
-- Health: HLT_MenHlth							/ Mental health (derived)
-- Safety: SFT_Safe								/ Feeling safe at night in neighbourhood
-- Safety: SFT_Victim						    / Being victim of crime 
-- Economic Standard of Living: EST_MatWell		/ Material wellbeing index (derived)
-- Economic Standard of Living: EST_EnoughMon   / Having enough money 
-- Economic Standard of Living: EST_Emp			/ Employment status at couple level 
-- Housing: HOU_Damp							/ Housing dampness is a problem
-- Housing: HOU_Cold							/ Housing cold is a problem
-- Housing: HOU_Crowded							/ Overcrowdedness
-- Social Connectedness: SC_Trust_police        / Trust in police
-- Social Connectedness: SC_Trust_HlthSys		/ Trust in the health system
-- Social Connectedness: SC_Trust_media			/ Trust in media
-- Social Connectedness: SC_Trust_parl			/ Trust in parliament
-- Social Connectedness: SC_Discrim				/ Being discriminated against in last 12 months
-- Social Connectedness: SC_Support				/ Feeling down/depressed -> how easy to talk to someone 
-- Social Connectedness: SC_ConFam				/ Enough contact with family
-- Social Connectedness: SC_ConFrd				/ Enough contact with friends
-- Social Connectedness: SC_Lonely				/ Time felt lonely in last four weeks







-- First select variables, modify them year by year from gss 
-- unite everything from six gss years together into a temporary table called #gss_all_temp



SELECT  
gss_person_2008.snz_uid
, gss_person_2008.snz_gss_hhld_uid as hh_id
, snz_gss_uid as gss_id
,null as hlfs_id
,null as hlfs_qrt
, gss_pq_interview_start_date as interview_date
, YEAR(gss_pq_Period_start_date) as survey_yr
,null as personID

 -----------DEMOGRAPHICS---------------
-----------------------------------------------------
, case when gss_pq_CORDV10 = 1 then 0 when gss_pq_CORDV10 = 2 then 1 else null end as DEM_Gend --0=man,1=woman
, gss_pq_CORDV9 as DEM_Age
,gss_pq_birth_month_nbr as DEM_birth_month
,gss_pq_birth_year_nbr as DEM_birth_year 
,gss_pq_ethnic_grp1_snz_ind as DEM_Euro
,gss_pq_ethnic_grp2_snz_ind as DEM_Maori
,gss_pq_ethnic_grp3_snz_ind as DEM_Pacific
,gss_pq_ethnic_grp4_snz_ind as DEM_Asian
,gss_pq_ethnic_grp5_snz_ind as DEM_MELAA
,gss_pq_ethnic_grp6_snz_ind as DEM_Other
,null as DEM_Disabled
--Migrant status derived from "were you born in NZ?"
,case when gss_pq_CORPQ11 = 2 then 1 when gss_pq_CORPQ11 = 1 then 0 else null end as DEM_Migrant 

 -----------SUBJECTIVE WELLEBING---------------
-----------------------------------------------------
,case
when gss_pq_CULQ04 =11 then 5
when gss_pq_CULQ04 =12 then 4
when gss_pq_CULQ04 =13 then 3
when gss_pq_CULQ04 =14 then 2
when gss_pq_CULQ04 =15 then 1
else null end as SW_Identity
, case 
when gss_pq_OLSQ01 =11 then 5
when gss_pq_OLSQ01 =12 then 4
when gss_pq_OLSQ01 =13 then 3
when gss_pq_OLSQ01 =14 then 2
when gss_pq_OLSQ01 =15 then 1
else null end as SW_LifeSat
,null as SW_FamWell
-----------HEALTH---------------
-----------------------
,case 
when gss_pq_HEAQ01 = 11 then 5
when gss_pq_HEAQ01 = 12 then 4
when gss_pq_HEAQ01 = 13 then 3
when gss_pq_HEAQ01 = 14 then 2
when gss_pq_HEAQ01 = 15 then 1
else null end as HLT_GenHlth
,case
when gss_pq_HEAQ08a = 11 then 5
when gss_pq_HEAQ08a = 12 then 4
when gss_pq_HEAQ08a = 13 then 3
when gss_pq_HEAQ08a = 14 then 2
when gss_pq_HEAQ08a = 15 then 1
else null end as HLT_MenHlth1
,case
when gss_pq_HEAQ08b = 11 then 5
when gss_pq_HEAQ08b = 12 then 4
when gss_pq_HEAQ08b = 13 then 3
when gss_pq_HEAQ08b = 14 then 2
when gss_pq_HEAQ08b = 15 then 1
else null end as HLT_MenHlth2
,case
when gss_pq_HEAQ08c = 11 then 1
when gss_pq_HEAQ08c = 12 then 2
when gss_pq_HEAQ08c = 13 then 3
when gss_pq_HEAQ08c = 14 then 4
when gss_pq_HEAQ08c = 15 then 5
else null end as HLT_MenHlth3
-----------SAFETY---------------
-----------------------
,case
when gss_pq_SAFQ01E = 11 then 5
when gss_pq_SAFQ01E = 12 then 4
when gss_pq_SAFQ01E = 13 then 3
when gss_pq_SAFQ01E = 14 then 2
when gss_pq_SAFQ01E = 15 then 1
else null end as SFT_Safe
,case 
when gss_pq_SAFQ02 = 1 then 1  
when gss_pq_SAFQ02 = 2 then 0 
else null end as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
, case when gss_pq_ELSIDV1 = 77 then null else gss_pq_ELSIDV1 end as EST_MatWell1 --(0-31) 
,null as EST_MatWell2 --(0-20)  
,null as EST_MatWell3 --(0-17)
,case
when gss_pq_ELSQ08 = 11 then 1
when gss_pq_ELSQ08 = 12 then 0
when gss_pq_ELSQ08 = 13 then 0
when gss_pq_ELSQ08 = 14 then 0
else NULL end as EST_EnoughMon

 -----------HOUSING---------------
-----------------------------------------------------
,gss_pq_HOUQ03_14 as HOU_Damp -- this is only damp NOT MOLD
,gss_pq_HOUQ03_15 as HOU_Cold
, case 
when gss_pq_houdv2 = 1 then 1
when gss_pq_houdv2 = 2 then 1
when gss_pq_houdv2 = 3 then 0 
when gss_pq_houdv2 = 4 then 0
when gss_pq_houdv2 = 5 then 0
else null end as HOU_Crowded

 -----------SOCIAL CONNECTEDNESS---------------
-----------------------------------------------------
,null as SC_Trust_police
,null as SC_Trust_parl
,null as SC_Trust_health
,null as SC_Trust_media
,case
when gss_pq_HUMQ05 = 2 then 0
when gss_pq_HUMQ05 = 1 then 1
when gss_pq_HUMQ05 = 88 then null
when gss_pq_HUMQ05 = 99 then null end as SC_Discrim
,null as SC_Support 
,case
when gss_pq_SOCQ05 = 11 then 3
when gss_pq_SOCQ05 = 12 then 2
when gss_pq_SOCQ05 = 13 then 1
else null end as SC_ConFam
,case
when gss_pq_SOCQ10 = 11 then 3
when gss_pq_SOCQ10 = 12 then 2
when gss_pq_SOCQ10 = 13 then 1
else null end as SC_ConFrd   
,null as SC_Lonely 
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
,DEM_Region_org
,DEM_Region_8
,case
when gss_pq_CORDV14 = 1 then 1
when gss_pq_CORDV14 = 2 then 0
when gss_pq_CORDV14 = 3 then 0
when gss_pq_CORDV14 = 77 then null
else NULL end as EST_Emp1
--save all the united waves into a temporary table
INTO #gss_all_temp
FROM IDI_Clean_202206.gss_clean.gss_person_2008

-------------------------- FAMILY STRUCTURE AND REGION   --------------------------
------------------------------------------------------------------------------------
-- here we use relationship data and household level data to derive variables and join them to person level data 
-- Note: "SQL uses a backward-logic": creating the family structure variables startes at the end of this chunk (Step 1 and ends at Step 8 - which ignores the aggregating and joining) 

left join (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,case when DEM_Region_org = '99' then null else DEM_Region_org end as DEM_Region_org 
,DEM_Region_8
-- Step 8: create family structure variables: Couple with dependent children, couple without dependent children, sole parents and single people
,case when father_mother>0 and partner_spouse>0 and dependent_children>0 then 1 else 0 end as FAM_CopDep
,case when (father_mother>0 and partner_spouse>0 and dependent_children=0) or (father_mother=0 and partner_spouse>0 and dependent_children=0) then 1 else 0 end as FAM_CopNoDep
,case when father_mother>0 and partner_spouse=0 and dependent_children>0 then 1 else 0 end as FAM_SoleDep
,case when (father_mother>0 and partner_spouse=0 and dependent_children=0) or (father_mother=0 and partner_spouse=0) then 1 else 0 end as FAM_Singles
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,partner_spouse
,father_mother
,DEM_Region_org
,DEM_Region_8
-- Step 7: gather dependent children for parents within household matrix
,sum(son_daughter_11+son_daughter_12+son_daughter_13+son_daughter_14+son_daughter_15+son_daughter_16+son_daughter_17+son_daughter_18+son_daughter_19+son_daughter_20+son_daughter_21+son_daughter_22+son_daughter_23+son_daughter_24) as dependent_children
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
-- Step 6: identify dependent children
,case when reln_11_father_mother = 11 then (case when age_person_11 < 18 then 1 else 0 end) else 0 end as son_daughter_11  
,case when reln_12_father_mother = 12 then (case when age_person_12 < 18 then 1 else 0 end) else 0 end as son_daughter_12 
,case when reln_13_father_mother = 13 then (case when age_person_13 < 18 then 1 else 0 end) else 0 end as son_daughter_13 
,case when reln_14_father_mother = 14 then (case when age_person_14 < 18 then 1 else 0 end) else 0 end as son_daughter_14 
,case when reln_15_father_mother = 15 then (case when age_person_15 < 18 then 1 else 0 end) else 0 end as son_daughter_15 
,case when reln_16_father_mother = 16 then (case when age_person_16 < 18 then 1 else 0 end) else 0 end as son_daughter_16 
,case when reln_17_father_mother = 17 then (case when age_person_17 < 18 then 1 else 0 end) else 0 end as son_daughter_17 
,case when reln_18_father_mother = 18 then (case when age_person_18 < 18 then 1 else 0 end) else 0 end as son_daughter_18
,case when reln_19_father_mother = 19 then (case when age_person_19 < 18 then 1 else 0 end) else 0 end as son_daughter_19
,case when reln_20_father_mother = 20 then (case when age_person_20 < 18 then 1 else 0 end) else 0 end as son_daughter_20 
,case when reln_21_father_mother = 21 then (case when age_person_21 < 18 then 1 else 0 end) else 0 end as son_daughter_21
,case when reln_22_father_mother = 22 then (case when age_person_22 < 18 then 1 else 0 end) else 0 end as son_daughter_22
,case when reln_23_father_mother = 23 then (case when age_person_23 < 18 then 1 else 0 end) else 0 end as son_daughter_23 
,case when reln_24_father_mother = 24 then (case when age_person_24 < 18 then 1 else 0 end) else 0 end as son_daughter_24
-- Step 5: gather parents within household matrix (value higher than 1 means that one father or mother have more than two children)
,sum(reln_11_father_mother+reln_12_father_mother+reln_13_father_mother+reln_14_father_mother+reln_15_father_mother+reln_16_father_mother+reln_17_father_mother+reln_18_father_mother+reln_19_father_mother+reln_20_father_mother+reln_21_father_mother+reln_22_father_mother+reln_23_father_mother+reln_24_father_mother) as father_mother
-- Step 4: gather spouse or partner within household matrix
,sum(reln_11_spouse_partner+reln_12_spouse_partner+reln_13_spouse_partner+reln_14_spouse_partner+reln_15_spouse_partner+reln_16_spouse_partner+reln_17_spouse_partner+reln_18_spouse_partner+reln_19_spouse_partner+reln_20_spouse_partner+reln_21_spouse_partner+reln_22_spouse_partner+reln_23_spouse_partner+reln_24_spouse_partner) as partner_spouse
from ( 
select person_2008.snz_uid
,person_2008.snz_gss_hhld_uid
,person_2008.gss_pq_collection_code
,DEM_Region_org
-- select and recode region 
,case 
when DEM_Region_org = '01' or DEM_Region_org = '04' or DEM_Region_org = '05' or DEM_Region_org = '06' then 1 
when DEM_Region_org = '02' then 2
when DEM_Region_org = '03' then 3
when DEM_Region_org = '07' or DEM_Region_org = '08' then 4
when DEM_Region_org = '09' then 5
when DEM_Region_org = '16' or DEM_Region_org = '17' or DEM_Region_org = '18' or DEM_Region_org = '12' then 6
when DEM_Region_org = '13' then 7
when DEM_Region_org = '14' or DEM_Region_org = '15' then 8 
else null end as DEM_Region_8 
-- Step 3: identify whether there is a partner or spouse
,case when gss_reln_relation_to_pers_11 = 'spouse or partner' then 1 else 0 end as reln_11_spouse_partner
,case when gss_reln_relation_to_pers_12 = 'spouse or partner' then 1 else 0 end as reln_12_spouse_partner
,case when gss_reln_relation_to_pers_13 = 'spouse or partner' then 1 else 0 end as reln_13_spouse_partner
,case when gss_reln_relation_to_pers_14 = 'spouse or partner' then 1 else 0 end as reln_14_spouse_partner
,case when gss_reln_relation_to_pers_15 = 'spouse or partner' then 1 else 0 end as reln_15_spouse_partner
,case when gss_reln_relation_to_pers_16 = 'spouse or partner' then 1 else 0 end as reln_16_spouse_partner
,case when gss_reln_relation_to_pers_17 = 'spouse or partner' then 1 else 0 end as reln_17_spouse_partner
,case when gss_reln_relation_to_pers_18 = 'spouse or partner' then 1 else 0 end as reln_18_spouse_partner
,case when gss_reln_relation_to_pers_19 = 'spouse or partner' then 1 else 0 end as reln_19_spouse_partner
,case when gss_reln_relation_to_pers_20 = 'spouse or partner' then 1 else 0 end as reln_20_spouse_partner
,case when gss_reln_relation_to_pers_21 = 'spouse or partner' then 1 else 0 end as reln_21_spouse_partner
,case when gss_reln_relation_to_pers_22 = 'spouse or partner' then 1 else 0 end as reln_22_spouse_partner
,case when gss_reln_relation_to_pers_23 = 'spouse or partner' then 1 else 0 end as reln_23_spouse_partner
,case when gss_reln_relation_to_pers_24 = 'spouse or partner' then 1 else 0 end as reln_24_spouse_partner
-- Step 2: identify whether there is a father or mother
,case when gss_reln_relation_to_pers_11 = 'father or mother' then 11 else 0 end as reln_11_father_mother
,case when gss_reln_relation_to_pers_12 = 'father or mother' then 12 else 0 end as reln_12_father_mother
,case when gss_reln_relation_to_pers_13 = 'father or mother' then 13 else 0 end as reln_13_father_mother
,case when gss_reln_relation_to_pers_14 = 'father or mother' then 14 else 0 end as reln_14_father_mother
,case when gss_reln_relation_to_pers_15 = 'father or mother' then 15 else 0 end as reln_15_father_mother
,case when gss_reln_relation_to_pers_16 = 'father or mother' then 16 else 0 end as reln_16_father_mother
,case when gss_reln_relation_to_pers_17 = 'father or mother' then 17 else 0 end as reln_17_father_mother
,case when gss_reln_relation_to_pers_18 = 'father or mother' then 18 else 0 end as reln_18_father_mother
,case when gss_reln_relation_to_pers_19 = 'father or mother' then 19 else 0 end as reln_19_father_mother
,case when gss_reln_relation_to_pers_20 = 'father or mother' then 20 else 0 end as reln_20_father_mother
,case when gss_reln_relation_to_pers_21 = 'father or mother' then 21 else 0 end as reln_21_father_mother
,case when gss_reln_relation_to_pers_22 = 'father or mother' then 22 else 0 end as reln_22_father_mother
,case when gss_reln_relation_to_pers_23 = 'father or mother' then 23 else 0 end as reln_23_father_mother
,case when gss_reln_relation_to_pers_24 = 'father or mother' then 24 else 0 end as reln_24_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23
,age_person_24
from IDI_Clean_202206.gss_clean.gss_person_2008 person_2008
left join IDI_Clean_202206.gss_clean.gss_relationship_2008 relationship_2008
on person_2008.snz_uid = relationship_2008.snz_uid
left join (
select 
household_2008.snz_gss_hhld_uid
,gss_reln_collection_code -- survey round identifier 
-- Step 1: Age by person within household for identifing dependent children 
,gss_hq_reg_council_08_code as DEM_Region_org
,max(case when gss_reln_person_number = 11 then gss_hq_CORDV9 else null end) as age_person_11
,max(case when gss_reln_person_number = 12 then gss_hq_CORDV9 else null end) as age_person_12
,max(case when gss_reln_person_number = 13 then gss_hq_CORDV9 else null end) as age_person_13
,max(case when gss_reln_person_number = 14 then gss_hq_CORDV9 else null end) as age_person_14
,max(case when gss_reln_person_number = 15 then gss_hq_CORDV9 else null end) as age_person_15
,max(case when gss_reln_person_number = 16 then gss_hq_CORDV9 else null end) as age_person_16
,max(case when gss_reln_person_number = 17 then gss_hq_CORDV9 else null end) as age_person_17
,max(case when gss_reln_person_number = 18 then gss_hq_CORDV9 else null end) as age_person_18
,max(case when gss_reln_person_number = 19 then gss_hq_CORDV9 else null end) as age_person_19
,max(case when gss_reln_person_number = 20 then gss_hq_CORDV9 else null end) as age_person_20
,max(case when gss_reln_person_number = 21 then gss_hq_CORDV9 else null end) as age_person_21
,max(case when gss_reln_person_number = 22 then gss_hq_CORDV9 else null end) as age_person_22
,max(case when gss_reln_person_number = 23 then gss_hq_CORDV9 else null end) as age_person_23
,max(case when gss_reln_person_number = 24 then gss_hq_CORDV9 else null end) as age_person_24
from IDI_Clean_202206.gss_clean.gss_relationship_2008 relationship_2008
left join IDI_Clean_202206.gss_clean.gss_household_2008 household_2008
on household_2008.snz_uid = relationship_2008.snz_uid
left join IDI_Clean_202206.gss_clean.gss_person_2008 person_2008
on person_2008.snz_uid = household_2008.snz_uid
-- this is multiple layers of aggregation
group by household_2008.snz_gss_hhld_uid,gss_reln_collection_code,gss_hq_reg_council_08_code) joined
on person_2008.snz_gss_hhld_uid = joined.snz_gss_hhld_uid) group1
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
,reln_11_father_mother
,reln_12_father_mother
,reln_13_father_mother
,reln_14_father_mother
,reln_15_father_mother
,reln_16_father_mother
,reln_17_father_mother
,reln_18_father_mother
,reln_19_father_mother
,reln_20_father_mother
,reln_21_father_mother
,reln_22_father_mother
,reln_23_father_mother
,reln_24_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23
,age_person_24) group2
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother,DEM_Region_org,DEM_Region_8) group3
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother, dependent_children,DEM_Region_org,DEM_Region_8) all_data
on gss_person_2008.snz_gss_hhld_uid = all_data.snz_gss_hhld_uid

-- here we move on to the next gss wave and repeat the same selection and joining procedurue as above 
UNION

SELECT  
gss_person_2010.snz_uid
, gss_person_2010.snz_gss_hhld_uid as hh_id
, snz_gss_uid as gss_id
,null as hlfs_id
,null as hlfs_qrt
, gss_pq_interview_start_date as interview_date
, YEAR(gss_pq_Period_start_date) as survey_yr
,null as personID
-----------DEMOGRAPHICS---------------
-----------------------------------------------------
, case when gss_pq_CORDV10 = 1 then 0 when gss_pq_CORDV10 = 2 then 1 else null end as DEM_Gend --0=man,1=woman
, gss_pq_CORDV9 as DEM_Age
,gss_pq_birth_month_nbr as DEM_birth_month
,gss_pq_birth_year_nbr as DEM_birth_year 
,gss_pq_ethnic_grp1_snz_ind as DEM_Euro
,gss_pq_ethnic_grp2_snz_ind as DEM_Maori
,gss_pq_ethnic_grp3_snz_ind as DEM_Pacific
,gss_pq_ethnic_grp4_snz_ind as DEM_Asian
,gss_pq_ethnic_grp5_snz_ind as DEM_MELAA
,gss_pq_ethnic_grp6_snz_ind as DEM_Other
,null as DEM_Disabled
--Migrant status derived from "were you born in NZ?"
,case when gss_pq_CORPQ11 = 2 then 1 when gss_pq_CORPQ11 = 1 then 0 else null end as DEM_Migrant 

 -----------SUBJECTIVE WELLEBING---------------
-----------------------------------------------------
,case
when gss_pq_CULQ04 =11 then 5
when gss_pq_CULQ04 =12 then 4
when gss_pq_CULQ04 =13 then 3
when gss_pq_CULQ04 =14 then 2
when gss_pq_CULQ04 =15 then 1
else null end as SW_Identity
, case 
when gss_pq_OLSQ01 =11 then 5
when gss_pq_OLSQ01 =12 then 4
when gss_pq_OLSQ01 =13 then 3
when gss_pq_OLSQ01 =14 then 2
when gss_pq_OLSQ01 =15 then 1
else null end as SW_LifeSat
,null as SW_FamWell
-----------HEALTH---------------
-----------------------
,case 
when gss_pq_HEAQ01 = 11 then 5
when gss_pq_HEAQ01 = 12 then 4
when gss_pq_HEAQ01 = 13 then 3
when gss_pq_HEAQ01 = 14 then 2
when gss_pq_HEAQ01 = 15 then 1
else null end as HLT_GenHlth
,case
when gss_pq_HEAQ08a = 11 then 5
when gss_pq_HEAQ08a = 12 then 4
when gss_pq_HEAQ08a = 13 then 3
when gss_pq_HEAQ08a = 14 then 2
when gss_pq_HEAQ08a = 15 then 1
else null end as HLT_MenHlth1
,case
when gss_pq_HEAQ08b = 11 then 5
when gss_pq_HEAQ08b = 12 then 4
when gss_pq_HEAQ08b = 13 then 3
when gss_pq_HEAQ08b = 14 then 2
when gss_pq_HEAQ08b = 15 then 1
else null end as HLT_MenHlth2
,case
when gss_pq_HEAQ08c = 11 then 1
when gss_pq_HEAQ08c = 12 then 2
when gss_pq_HEAQ08c = 13 then 3
when gss_pq_HEAQ08c = 14 then 4
when gss_pq_HEAQ08c = 15 then 5
else null end as HLT_MenHlth3
-----------SAFETY---------------
-----------------------
,case
when gss_pq_SAFQ01E = 11 then 5
when gss_pq_SAFQ01E = 12 then 4
when gss_pq_SAFQ01E = 13 then 3
when gss_pq_SAFQ01E = 14 then 2
when gss_pq_SAFQ01E = 15 then 1
else null end as SFT_Safe
,case 
when gss_pq_SAFQ02 = 1 then 1  
when gss_pq_SAFQ02 = 2 then 0 
else null end as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
, case when gss_pq_ELSIDV1 = 77 then null else gss_pq_ELSIDV1 end as EST_MatWell1 --(0-31) 
,null as EST_MatWell2 --(0-20)  
,null as EST_MatWell3 --(0-17)
,case
when gss_pq_ELSQ08 = 11 then 1
when gss_pq_ELSQ08 = 12 then 0
when gss_pq_ELSQ08 = 13 then 0
when gss_pq_ELSQ08 = 14 then 0
else NULL end as EST_EnoughMon
 -----------HOUSING---------------
-----------------------------------------------------
,gss_pq_HOUQ03_14 as HOU_Damp -- this is only damp NOT MOLD
,gss_pq_HOUQ03_15 as HOU_Cold
, case 
when gss_pq_houdv2 = 1 then 1
when gss_pq_houdv2 = 2 then 1
when gss_pq_houdv2 = 3 then 0 
when gss_pq_houdv2 = 4 then 0
when gss_pq_houdv2 = 5 then 0
else null end as HOU_Crowded

 -----------SOCIAL CONNECTEDNESS---------------
 ----------------------------------------------
,null as SC_Trust_police
,null as SC_Trust_parl
,null as SC_Trust_health
,null as SC_Trust_media
,case
when gss_pq_HUMQ05 = 2 then 0
when gss_pq_HUMQ05 = 1 then 1 
when gss_pq_HUMQ05 = 88 then null
when gss_pq_HUMQ05 = 99 then null end as SC_Discrim
,null as SC_Support 
,case
when gss_pq_SOCQ05 = 11 then 3
when gss_pq_SOCQ05 = 12 then 2
when gss_pq_SOCQ05 = 13 then 1
else null end as SC_ConFam
,case
when gss_pq_SOCQ10 = 11 then 3
when gss_pq_SOCQ10 = 12 then 2
when gss_pq_SOCQ10 = 13 then 1
else null end as SC_ConFrd   
,null as SC_Lonely 
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
,DEM_Region_org
,DEM_Region_8
,case
when gss_pq_CORDV14 = 1 then 1
when gss_pq_CORDV14 = 2 then 0
when gss_pq_CORDV14 = 3 then 0
when gss_pq_CORDV14 = 77 then null
else NULL end as EST_Emp1
FROM IDI_Clean_202206.gss_clean.gss_person_2010

-------------------------- FAMILY STRUCTURE AND REGION  --------------------------
------------------------------------------------------------------------------------
left join (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,case when DEM_Region_org = '99' then null else DEM_Region_org end as DEM_Region_org 
,DEM_Region_8
,case when father_mother>0 and partner_spouse>0 and dependent_children>0 then 1 else 0 end as FAM_CopDep
,case when (father_mother>0 and partner_spouse>0 and dependent_children=0) or (father_mother=0 and partner_spouse>0 and dependent_children=0) then 1 else 0 end as FAM_CopNoDep
,case when father_mother>0 and partner_spouse=0 and dependent_children>0 then 1 else 0 end as FAM_SoleDep
,case when (father_mother>0 and partner_spouse=0 and dependent_children=0) or (father_mother=0 and partner_spouse=0) then 1 else 0 end as FAM_Singles
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,partner_spouse
,father_mother
,DEM_Region_org
,DEM_Region_8
,sum(son_daughter_11+son_daughter_12+son_daughter_13+son_daughter_14+son_daughter_15+son_daughter_16+son_daughter_17+son_daughter_18+son_daughter_19+son_daughter_20+son_daughter_21+son_daughter_22+son_daughter_23+son_daughter_24) as dependent_children
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
,case when reln_11_father_mother = 11 then (case when age_person_11 < 18 then 1 else 0 end) else 0 end as son_daughter_11  
,case when reln_12_father_mother = 12 then (case when age_person_12 < 18 then 1 else 0 end) else 0 end as son_daughter_12 
,case when reln_13_father_mother = 13 then (case when age_person_13 < 18 then 1 else 0 end) else 0 end as son_daughter_13 
,case when reln_14_father_mother = 14 then (case when age_person_14 < 18 then 1 else 0 end) else 0 end as son_daughter_14 
,case when reln_15_father_mother = 15 then (case when age_person_15 < 18 then 1 else 0 end) else 0 end as son_daughter_15 
,case when reln_16_father_mother = 16 then (case when age_person_16 < 18 then 1 else 0 end) else 0 end as son_daughter_16 
,case when reln_17_father_mother = 17 then (case when age_person_17 < 18 then 1 else 0 end) else 0 end as son_daughter_17 
,case when reln_18_father_mother = 18 then (case when age_person_18 < 18 then 1 else 0 end) else 0 end as son_daughter_18
,case when reln_19_father_mother = 19 then (case when age_person_19 < 18 then 1 else 0 end) else 0 end as son_daughter_19
,case when reln_20_father_mother = 20 then (case when age_person_20 < 18 then 1 else 0 end) else 0 end as son_daughter_20 
,case when reln_21_father_mother = 21 then (case when age_person_21 < 18 then 1 else 0 end) else 0 end as son_daughter_21
,case when reln_22_father_mother = 22 then (case when age_person_22 < 18 then 1 else 0 end) else 0 end as son_daughter_22
,case when reln_23_father_mother = 23 then (case when age_person_23 < 18 then 1 else 0 end) else 0 end as son_daughter_23 
,case when reln_24_father_mother = 24 then (case when age_person_24 < 18 then 1 else 0 end) else 0 end as son_daughter_24
,sum(reln_11_father_mother+reln_12_father_mother+reln_13_father_mother+reln_14_father_mother+reln_15_father_mother+reln_16_father_mother+reln_17_father_mother+reln_18_father_mother+reln_19_father_mother+reln_20_father_mother+reln_21_father_mother+reln_22_father_mother+reln_23_father_mother+reln_24_father_mother) as father_mother
,sum(reln_11_spouse_partner+reln_12_spouse_partner+reln_13_spouse_partner+reln_14_spouse_partner+reln_15_spouse_partner+reln_16_spouse_partner+reln_17_spouse_partner+reln_18_spouse_partner+reln_19_spouse_partner+reln_20_spouse_partner+reln_21_spouse_partner+reln_22_spouse_partner+reln_23_spouse_partner+reln_24_spouse_partner) as partner_spouse
from ( 
select person_2010.snz_uid
,person_2010.snz_gss_hhld_uid
,person_2010.gss_pq_collection_code
,DEM_Region_org
,case 
when DEM_Region_org = '01' or DEM_Region_org = '04' or DEM_Region_org = '05' or DEM_Region_org = '06' then 1 
when DEM_Region_org = '02' then 2
when DEM_Region_org = '03' then 3
when DEM_Region_org = '07' or DEM_Region_org = '08' then 4
when DEM_Region_org = '09' then 5
when DEM_Region_org = '16' or DEM_Region_org = '17' or DEM_Region_org = '18' or DEM_Region_org = '12' then 6
when DEM_Region_org = '13' then 7
when DEM_Region_org = '14' or DEM_Region_org = '15' then 8 
else null end as DEM_Region_8 
,case when gss_reln_relation_to_pers_11 = 'spouse or partner' then 1 else 0 end as reln_11_spouse_partner
,case when gss_reln_relation_to_pers_12 = 'spouse or partner' then 1 else 0 end as reln_12_spouse_partner
,case when gss_reln_relation_to_pers_13 = 'spouse or partner' then 1 else 0 end as reln_13_spouse_partner
,case when gss_reln_relation_to_pers_14 = 'spouse or partner' then 1 else 0 end as reln_14_spouse_partner
,case when gss_reln_relation_to_pers_15 = 'spouse or partner' then 1 else 0 end as reln_15_spouse_partner
,case when gss_reln_relation_to_pers_16 = 'spouse or partner' then 1 else 0 end as reln_16_spouse_partner
,case when gss_reln_relation_to_pers_17 = 'spouse or partner' then 1 else 0 end as reln_17_spouse_partner
,case when gss_reln_relation_to_pers_18 = 'spouse or partner' then 1 else 0 end as reln_18_spouse_partner
,case when gss_reln_relation_to_pers_19 = 'spouse or partner' then 1 else 0 end as reln_19_spouse_partner
,case when gss_reln_relation_to_pers_20 = 'spouse or partner' then 1 else 0 end as reln_20_spouse_partner
,case when gss_reln_relation_to_pers_21 = 'spouse or partner' then 1 else 0 end as reln_21_spouse_partner
,case when gss_reln_relation_to_pers_22 = 'spouse or partner' then 1 else 0 end as reln_22_spouse_partner
,case when gss_reln_relation_to_pers_23 = 'spouse or partner' then 1 else 0 end as reln_23_spouse_partner
,case when gss_reln_relation_to_pers_24 = 'spouse or partner' then 1 else 0 end as reln_24_spouse_partner

,case when gss_reln_relation_to_pers_11 = 'father or mother' then 11 else 0 end as reln_11_father_mother
,case when gss_reln_relation_to_pers_12 = 'father or mother' then 12 else 0 end as reln_12_father_mother
,case when gss_reln_relation_to_pers_13 = 'father or mother' then 13 else 0 end as reln_13_father_mother
,case when gss_reln_relation_to_pers_14 = 'father or mother' then 14 else 0 end as reln_14_father_mother
,case when gss_reln_relation_to_pers_15 = 'father or mother' then 15 else 0 end as reln_15_father_mother
,case when gss_reln_relation_to_pers_16 = 'father or mother' then 16 else 0 end as reln_16_father_mother
,case when gss_reln_relation_to_pers_17 = 'father or mother' then 17 else 0 end as reln_17_father_mother
,case when gss_reln_relation_to_pers_18 = 'father or mother' then 18 else 0 end as reln_18_father_mother
,case when gss_reln_relation_to_pers_19 = 'father or mother' then 19 else 0 end as reln_19_father_mother
,case when gss_reln_relation_to_pers_20 = 'father or mother' then 20 else 0 end as reln_20_father_mother
,case when gss_reln_relation_to_pers_21 = 'father or mother' then 21 else 0 end as reln_21_father_mother
,case when gss_reln_relation_to_pers_22 = 'father or mother' then 22 else 0 end as reln_22_father_mother
,case when gss_reln_relation_to_pers_23 = 'father or mother' then 23 else 0 end as reln_23_father_mother
,case when gss_reln_relation_to_pers_24 = 'father or mother' then 24 else 0 end as reln_24_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23
,age_person_24
from IDI_Clean_202206.gss_clean.gss_person_2010 person_2010
left join IDI_Clean_202206.gss_clean.gss_relationship_2010 relationship_2010
on person_2010.snz_uid = relationship_2010.snz_uid
left join (
select 
household_2010.snz_gss_hhld_uid
,gss_reln_collection_code -- survey round identifier 
,gss_hq_reg_council_08_code as DEM_Region_org
,max(case when gss_reln_person_number = 11 then gss_hq_CORDV9 else null end) as age_person_11
,max(case when gss_reln_person_number = 12 then gss_hq_CORDV9 else null end) as age_person_12
,max(case when gss_reln_person_number = 13 then gss_hq_CORDV9 else null end) as age_person_13
,max(case when gss_reln_person_number = 14 then gss_hq_CORDV9 else null end) as age_person_14
,max(case when gss_reln_person_number = 15 then gss_hq_CORDV9 else null end) as age_person_15
,max(case when gss_reln_person_number = 16 then gss_hq_CORDV9 else null end) as age_person_16
,max(case when gss_reln_person_number = 17 then gss_hq_CORDV9 else null end) as age_person_17
,max(case when gss_reln_person_number = 18 then gss_hq_CORDV9 else null end) as age_person_18
,max(case when gss_reln_person_number = 19 then gss_hq_CORDV9 else null end) as age_person_19
,max(case when gss_reln_person_number = 20 then gss_hq_CORDV9 else null end) as age_person_20
,max(case when gss_reln_person_number = 21 then gss_hq_CORDV9 else null end) as age_person_21
,max(case when gss_reln_person_number = 22 then gss_hq_CORDV9 else null end) as age_person_22
,max(case when gss_reln_person_number = 23 then gss_hq_CORDV9 else null end) as age_person_23
,max(case when gss_reln_person_number = 24 then gss_hq_CORDV9 else null end) as age_person_24
from IDI_Clean_202206.gss_clean.gss_relationship_2010 relationship_2010
left join IDI_Clean_202206.gss_clean.gss_household_2010 household_2010
on household_2010.snz_uid = relationship_2010.snz_uid
left join IDI_Clean_202206.gss_clean.gss_person_2010 person_2010
on person_2010.snz_uid = household_2010.snz_uid
group by household_2010.snz_gss_hhld_uid,gss_reln_collection_code,gss_hq_reg_council_08_code) joined
on person_2010.snz_gss_hhld_uid = joined.snz_gss_hhld_uid) group1
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
,reln_11_father_mother
,reln_12_father_mother
,reln_13_father_mother
,reln_14_father_mother
,reln_15_father_mother
,reln_16_father_mother
,reln_17_father_mother
,reln_18_father_mother
,reln_19_father_mother
,reln_20_father_mother
,reln_21_father_mother
,reln_22_father_mother
,reln_23_father_mother
,reln_24_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23
,age_person_24) group2
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother,DEM_Region_org,DEM_Region_8) group3
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother, dependent_children,DEM_Region_org,DEM_Region_8) all_data
on gss_person_2010.snz_gss_hhld_uid = all_data.snz_gss_hhld_uid

UNION

SELECT  
gss_person_2012.snz_uid
, gss_person_2012.snz_gss_hhld_uid as hh_id
, snz_gss_uid as gss_id
,null as hlfs_id
,null as hlfs_qrt
, gss_pq_interview_start_date as interview_date
, YEAR(gss_pq_Period_start_date) as survey_yr
,null as personID

 -----------DEMOGRAPHICS---------------
-----------------------------------------------------
, case when gss_pq_CORDV10 = 1 then 0 when gss_pq_CORDV10 = 2 then 1 else null end as DEM_Gend --0=man,1=woman
, gss_pq_CORDV9 as DEM_Age
,gss_pq_birth_month_nbr as DEM_birth_month
,gss_pq_birth_year_nbr as DEM_birth_year 
,gss_pq_ethnic_grp1_snz_ind as DEM_Euro
,gss_pq_ethnic_grp2_snz_ind as DEM_Maori
,gss_pq_ethnic_grp3_snz_ind as DEM_Pacific
,gss_pq_ethnic_grp4_snz_ind as DEM_Asian
,gss_pq_ethnic_grp5_snz_ind as DEM_MELAA
,gss_pq_ethnic_grp6_snz_ind as DEM_Other
,null as DEM_Disabled
--Migrant status derived from "were you born in NZ?"
,case when gss_pq_CORPQ11 = 2 then 1 when gss_pq_CORPQ11 = 1 then 0 else null end as DEM_Migrant 

 -----------SUBJECTIVE WELLEBING---------------
-----------------------------------------------------
,case
when gss_pq_CULQ04 =11 then 5
when gss_pq_CULQ04 =12 then 4
when gss_pq_CULQ04 =13 then 3
when gss_pq_CULQ04 =14 then 2
when gss_pq_CULQ04 =15 then 1
else null end as SW_Identity
, case 
when gss_pq_OLSQ01 =11 then 5
when gss_pq_OLSQ01 =12 then 4
when gss_pq_OLSQ01 =13 then 3
when gss_pq_OLSQ01 =14 then 2
when gss_pq_OLSQ01 =15 then 1
else null end as SW_LifeSat
,null as SW_FamWell
-----------HEALTH---------------
-----------------------
,case 
when gss_pq_HEAQ01 = 11 then 5
when gss_pq_HEAQ01 = 12 then 4
when gss_pq_HEAQ01 = 13 then 3
when gss_pq_HEAQ01 = 14 then 2
when gss_pq_HEAQ01 = 15 then 1
else NULL end as HLT_GenHlth
,case
when gss_pq_HEAQ08a = 11 then 5
when gss_pq_HEAQ08a = 12 then 4
when gss_pq_HEAQ08a = 13 then 3
when gss_pq_HEAQ08a = 14 then 2
when gss_pq_HEAQ08a = 15 then 1
else null end as HLT_MenHlth1
,case
when gss_pq_HEAQ08b = 11 then 5
when gss_pq_HEAQ08b = 12 then 4
when gss_pq_HEAQ08b = 13 then 3
when gss_pq_HEAQ08b = 14 then 2
when gss_pq_HEAQ08b = 15 then 1
else null end as HLT_MenHlth2
,case
when gss_pq_HEAQ08c = 11 then 1
when gss_pq_HEAQ08c = 12 then 2
when gss_pq_HEAQ08c = 13 then 3
when gss_pq_HEAQ08c = 14 then 4
when gss_pq_HEAQ08c = 15 then 5
else null end as HLT_MenHlth3
-----------SAFETY---------------
-----------------------
,case
when gss_pq_SAFQ01E = 11 then 5
when gss_pq_SAFQ01E = 12 then 4
when gss_pq_SAFQ01E = 13 then 3
when gss_pq_SAFQ01E = 14 then 2
when gss_pq_SAFQ01E = 15 then 1
else NULL end as SFT_Safe
,case 
when gss_pq_SAFQ02 = 1 then 1  
when gss_pq_SAFQ02 = 2 then 0 
else NULL end as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
, case when gss_pq_ELSIDV1 = 77 then null else gss_pq_ELSIDV1 end as EST_MatWell1 --(0-31) 
,null as EST_MatWell2 --(0-20)  
,null as EST_MatWell3 --(0-17)
,case
when gss_pq_ELSQ08 = 11 then 1
when gss_pq_ELSQ08 = 12 then 0
when gss_pq_ELSQ08 = 13 then 0
when gss_pq_ELSQ08 = 14 then 0
else NULL end as EST_EnoughMon  
 -----------HOUSING---------------
-----------------------------------------------------
,gss_pq_HOUQ03_14 as HOU_Damp -- this is only damp NOT MOLD
,gss_pq_HOUQ03_15 as HOU_Cold
, case 
when gss_pq_houdv2 = 1 then 1
when gss_pq_houdv2 = 2 then 1
when gss_pq_houdv2 = 3 then 0 
when gss_pq_houdv2 = 4 then 0
when gss_pq_houdv2 = 5 then 0
else null end as HOU_Crowded

 -----------SOCIAL CONNECTEDNESS---------------
-----------------------------------------------------
,null as SC_Trust_police
,null as SC_Trust_parl
,null as SC_Trust_health
,null as SC_Trust_media
,case
when gss_pq_HUMQ05 = 2 then 0
when gss_pq_HUMQ05 = 1 then 1
when gss_pq_HUMQ05 = 88 then null
when gss_pq_HUMQ05 = 99 then null end as SC_Discrim
,null as SC_Support 
,case
when gss_pq_SOCQ05 = 11 then 3
when gss_pq_SOCQ05 = 12 then 2
when gss_pq_SOCQ05 = 13 then 1
else null end as SC_ConFam
,case
when gss_pq_SOCQ10 = 11 then 3
when gss_pq_SOCQ10 = 12 then 2
when gss_pq_SOCQ10 = 13 then 1
else null end as SC_ConFrd   
,null as SC_Lonely 
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
,DEM_Region_org
,DEM_Region_8
,case
when gss_pq_CORDV14 = 1 then 1
when gss_pq_CORDV14 = 2 then 0
when gss_pq_CORDV14 = 3 then 0
when gss_pq_CORDV14 = 77 then null
else NULL end as EST_Emp1
FROM IDI_Clean_202206.gss_clean.gss_person_2012

-------------------------- FAMILY STRUCTURE AND REGION --------------------------
------------------------------------------------------------------------------------
left join (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,case when DEM_Region_org = '99' then null else DEM_Region_org end as DEM_Region_org 
,DEM_Region_8
,case when father_mother>0 and partner_spouse>0 and dependent_children>0 then 1 else 0 end as FAM_CopDep
,case when (father_mother>0 and partner_spouse>0 and dependent_children=0) or (father_mother=0 and partner_spouse>0 and dependent_children=0) then 1 else 0 end as FAM_CopNoDep
,case when father_mother>0 and partner_spouse=0 and dependent_children>0 then 1 else 0 end as FAM_SoleDep
,case when (father_mother>0 and partner_spouse=0 and dependent_children=0) or (father_mother=0 and partner_spouse=0) then 1 else 0 end as FAM_Singles
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,partner_spouse
,father_mother
,DEM_Region_org
,DEM_Region_8
,sum(son_daughter_11+son_daughter_12+son_daughter_13+son_daughter_14+son_daughter_15+son_daughter_16+son_daughter_17+son_daughter_18+son_daughter_19+son_daughter_20+son_daughter_21+son_daughter_22+son_daughter_23) as dependent_children
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
,case when reln_11_father_mother = 11 then (case when age_person_11 < 18 then 1 else 0 end) else 0 end as son_daughter_11  
,case when reln_12_father_mother = 12 then (case when age_person_12 < 18 then 1 else 0 end) else 0 end as son_daughter_12 
,case when reln_13_father_mother = 13 then (case when age_person_13 < 18 then 1 else 0 end) else 0 end as son_daughter_13 
,case when reln_14_father_mother = 14 then (case when age_person_14 < 18 then 1 else 0 end) else 0 end as son_daughter_14 
,case when reln_15_father_mother = 15 then (case when age_person_15 < 18 then 1 else 0 end) else 0 end as son_daughter_15 
,case when reln_16_father_mother = 16 then (case when age_person_16 < 18 then 1 else 0 end) else 0 end as son_daughter_16 
,case when reln_17_father_mother = 17 then (case when age_person_17 < 18 then 1 else 0 end) else 0 end as son_daughter_17 
,case when reln_18_father_mother = 18 then (case when age_person_18 < 18 then 1 else 0 end) else 0 end as son_daughter_18
,case when reln_19_father_mother = 19 then (case when age_person_19 < 18 then 1 else 0 end) else 0 end as son_daughter_19
,case when reln_20_father_mother = 20 then (case when age_person_20 < 18 then 1 else 0 end) else 0 end as son_daughter_20 
,case when reln_21_father_mother = 21 then (case when age_person_21 < 18 then 1 else 0 end) else 0 end as son_daughter_21
,case when reln_22_father_mother = 22 then (case when age_person_22 < 18 then 1 else 0 end) else 0 end as son_daughter_22
,case when reln_23_father_mother = 23 then (case when age_person_23 < 18 then 1 else 0 end) else 0 end as son_daughter_23 
,sum(reln_11_father_mother+reln_12_father_mother+reln_13_father_mother+reln_14_father_mother+reln_15_father_mother+reln_16_father_mother+reln_17_father_mother+reln_18_father_mother+reln_19_father_mother+reln_20_father_mother+reln_21_father_mother+reln_22_father_mother+reln_23_father_mother) as father_mother
,sum(reln_11_spouse_partner+reln_12_spouse_partner+reln_13_spouse_partner+reln_14_spouse_partner+reln_15_spouse_partner+reln_16_spouse_partner+reln_17_spouse_partner+reln_18_spouse_partner+reln_19_spouse_partner+reln_20_spouse_partner+reln_21_spouse_partner+reln_22_spouse_partner+reln_23_spouse_partner) as partner_spouse
from ( 
select person_2012.snz_uid
,person_2012.snz_gss_hhld_uid
,person_2012.gss_pq_collection_code
,DEM_Region_org
,case 
when DEM_Region_org = '01' or DEM_Region_org = '04' or DEM_Region_org = '05' or DEM_Region_org = '06' then 1 
when DEM_Region_org = '02' then 2
when DEM_Region_org = '03' then 3
when DEM_Region_org = '07' or DEM_Region_org = '08' then 4
when DEM_Region_org = '09' then 5
when DEM_Region_org = '16' or DEM_Region_org = '17' or DEM_Region_org = '18' or DEM_Region_org = '12' then 6
when DEM_Region_org = '13' then 7
when DEM_Region_org = '14' or DEM_Region_org = '15' then 8 
else null end as DEM_Region_8 
,case when gss_reln_relation_to_pers_11 = 'spouse or partner' then 1 else 0 end as reln_11_spouse_partner
,case when gss_reln_relation_to_pers_12 = 'spouse or partner' then 1 else 0 end as reln_12_spouse_partner
,case when gss_reln_relation_to_pers_13 = 'spouse or partner' then 1 else 0 end as reln_13_spouse_partner
,case when gss_reln_relation_to_pers_14 = 'spouse or partner' then 1 else 0 end as reln_14_spouse_partner
,case when gss_reln_relation_to_pers_15 = 'spouse or partner' then 1 else 0 end as reln_15_spouse_partner
,case when gss_reln_relation_to_pers_16 = 'spouse or partner' then 1 else 0 end as reln_16_spouse_partner
,case when gss_reln_relation_to_pers_17 = 'spouse or partner' then 1 else 0 end as reln_17_spouse_partner
,case when gss_reln_relation_to_pers_18 = 'spouse or partner' then 1 else 0 end as reln_18_spouse_partner
,case when gss_reln_relation_to_pers_19 = 'spouse or partner' then 1 else 0 end as reln_19_spouse_partner
,case when gss_reln_relation_to_pers_20 = 'spouse or partner' then 1 else 0 end as reln_20_spouse_partner
,case when gss_reln_relation_to_pers_21 = 'spouse or partner' then 1 else 0 end as reln_21_spouse_partner
,case when gss_reln_relation_to_pers_22 = 'spouse or partner' then 1 else 0 end as reln_22_spouse_partner
,case when gss_reln_relation_to_pers_23 = 'spouse or partner' then 1 else 0 end as reln_23_spouse_partner

,case when gss_reln_relation_to_pers_11 = 'father or mother' then 11 else 0 end as reln_11_father_mother
,case when gss_reln_relation_to_pers_12 = 'father or mother' then 12 else 0 end as reln_12_father_mother
,case when gss_reln_relation_to_pers_13 = 'father or mother' then 13 else 0 end as reln_13_father_mother
,case when gss_reln_relation_to_pers_14 = 'father or mother' then 14 else 0 end as reln_14_father_mother
,case when gss_reln_relation_to_pers_15 = 'father or mother' then 15 else 0 end as reln_15_father_mother
,case when gss_reln_relation_to_pers_16 = 'father or mother' then 16 else 0 end as reln_16_father_mother
,case when gss_reln_relation_to_pers_17 = 'father or mother' then 17 else 0 end as reln_17_father_mother
,case when gss_reln_relation_to_pers_18 = 'father or mother' then 18 else 0 end as reln_18_father_mother
,case when gss_reln_relation_to_pers_19 = 'father or mother' then 19 else 0 end as reln_19_father_mother
,case when gss_reln_relation_to_pers_20 = 'father or mother' then 20 else 0 end as reln_20_father_mother
,case when gss_reln_relation_to_pers_21 = 'father or mother' then 21 else 0 end as reln_21_father_mother
,case when gss_reln_relation_to_pers_22 = 'father or mother' then 22 else 0 end as reln_22_father_mother
,case when gss_reln_relation_to_pers_23 = 'father or mother' then 23 else 0 end as reln_23_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23
from IDI_Clean_202206.gss_clean.gss_person_2012 person_2012
left join IDI_Clean_202206.gss_clean.gss_relationship_2012 relationship_2012
on person_2012.snz_uid = relationship_2012.snz_uid
left join (
select 
household_2012.snz_gss_hhld_uid
,gss_reln_collection_code -- survey round identifier 
,gss_hq_reg_council_08_code as DEM_Region_org
,max(case when gss_reln_person_number = 11 then gss_hq_CORDV9 else null end) as age_person_11
,max(case when gss_reln_person_number = 12 then gss_hq_CORDV9 else null end) as age_person_12
,max(case when gss_reln_person_number = 13 then gss_hq_CORDV9 else null end) as age_person_13
,max(case when gss_reln_person_number = 14 then gss_hq_CORDV9 else null end) as age_person_14
,max(case when gss_reln_person_number = 15 then gss_hq_CORDV9 else null end) as age_person_15
,max(case when gss_reln_person_number = 16 then gss_hq_CORDV9 else null end) as age_person_16
,max(case when gss_reln_person_number = 17 then gss_hq_CORDV9 else null end) as age_person_17
,max(case when gss_reln_person_number = 18 then gss_hq_CORDV9 else null end) as age_person_18
,max(case when gss_reln_person_number = 19 then gss_hq_CORDV9 else null end) as age_person_19
,max(case when gss_reln_person_number = 20 then gss_hq_CORDV9 else null end) as age_person_20
,max(case when gss_reln_person_number = 21 then gss_hq_CORDV9 else null end) as age_person_21
,max(case when gss_reln_person_number = 22 then gss_hq_CORDV9 else null end) as age_person_22
,max(case when gss_reln_person_number = 23 then gss_hq_CORDV9 else null end) as age_person_23
from IDI_Clean_202206.gss_clean.gss_relationship_2012 relationship_2012
left join IDI_Clean_202206.gss_clean.gss_household_2012 household_2012
on household_2012.snz_uid = relationship_2012.snz_uid
left join IDI_Clean_202206.gss_clean.gss_person_2010 person_2012
on person_2012.snz_uid = household_2012.snz_uid
group by household_2012.snz_gss_hhld_uid,gss_reln_collection_code,gss_hq_reg_council_08_code) joined
on person_2012.snz_gss_hhld_uid = joined.snz_gss_hhld_uid) group1
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
,reln_11_father_mother
,reln_12_father_mother
,reln_13_father_mother
,reln_14_father_mother
,reln_15_father_mother
,reln_16_father_mother
,reln_17_father_mother
,reln_18_father_mother
,reln_19_father_mother
,reln_20_father_mother
,reln_21_father_mother
,reln_22_father_mother
,reln_23_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23) group2
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother,DEM_Region_org,DEM_Region_8) group3
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother, dependent_children,DEM_Region_org,DEM_Region_8) all_data
on gss_person_2012.snz_gss_hhld_uid = all_data.snz_gss_hhld_uid


UNION

SELECT  
gss_person.snz_uid
, gss_person.snz_gss_hhld_uid as hh_id
, snz_gss_uid as gss_id
,null as hlfs_id
,null as hlfs_qrt
,gss_pq_PQinterview_date as interview_date
, YEAR(gss_pq_HQinterview_date) as survey_yr
, gss_pq_person_number as personID
-----------DEMOGRAPHICS---------------
-----------------------

,case when gss_pq_dvsex_code = 1 then 0 when gss_pq_dvsex_code = 2 then 1 else null end as DEM_Gend --0=man,1=woman
,gss_pq_dvage_code  as DEM_Age
,gss_pq_birth_month_nbr as DEM_birth_month
,gss_pq_birth_year_nbr as DEM_birth_year
,gss_pq_ethnic_grp1_snz_ind as DEM_Euro
,gss_pq_ethnic_grp2_snz_ind as DEM_Maori
,gss_pq_ethnic_grp3_snz_ind as DEM_Pacific
,gss_pq_ethnic_grp4_snz_ind as DEM_Asian
,gss_pq_ethnic_grp5_snz_ind as DEM_MELAA
,gss_pq_ethnic_grp6_snz_ind as DEM_Other
,case when gss_pq_disabled_dv_code =1 then 1 when gss_pq_disabled_dv_code = 2 then 0 else null end as DEM_Disabled
,case 
when gss_pq_mig_stat_code = 1 then 0 
when gss_pq_mig_stat_code = 2 then 0 
when gss_pq_mig_stat_code = 3 then 0 
when gss_pq_mig_stat_code = 4 then 1
when gss_pq_mig_stat_code = 5 then 1
when gss_pq_mig_stat_code = 6 then 1
when gss_pq_mig_stat_code = 77 then null 
else gss_pq_mig_stat_code end as DEM_Migrant
--Subjective wellbeing
-----------------------
,case
when gss_pq_cult_identity_code =11 then 5
when gss_pq_cult_identity_code =12 then 4
when gss_pq_cult_identity_code =13 then 3
when gss_pq_cult_identity_code =14 then 2
when gss_pq_cult_identity_code =15 then 1
else NULL end as SW_Identity
, case 
when gss_pq_feel_life_code =0 then 1
when gss_pq_feel_life_code =1 then 1
when gss_pq_feel_life_code =2 then 1
when gss_pq_feel_life_code =3 then 1
when gss_pq_feel_life_code =4 then 2
when gss_pq_feel_life_code =5 then 3
when gss_pq_feel_life_code =6 then 4 
when gss_pq_feel_life_code =7 then 4
when gss_pq_feel_life_code =8 then 4
when gss_pq_feel_life_code =9 then 5 
when gss_pq_feel_life_code =10 then 5
else null end as SW_LifeSat
,case
when gss_pq_fam_wellbeing_code =11 then null
when gss_pq_fam_wellbeing_code =12 then null
when gss_pq_fam_wellbeing_code =88 then null
when gss_pq_fam_wellbeing_code =99 then null else gss_pq_fam_wellbeing_code end as SW_FamWell

-----------HEALTH---------------
-----------------------
,case 
when gss_pq_health_excel_poor_code = 11 then 5
when gss_pq_health_excel_poor_code = 12 then 4
when gss_pq_health_excel_poor_code = 13 then 3
when gss_pq_health_excel_poor_code = 14 then 2
when gss_pq_health_excel_poor_code = 15 then 1
else NULL end as HLT_GenHlth
,case
when gss_pq_felt_calm18_code = 11 then 6
when gss_pq_felt_calm_code = 11 or gss_pq_felt_calm18_code = 12 then 5
when gss_pq_felt_calm_code = 12 or gss_pq_felt_calm18_code = 13 then 4
when gss_pq_felt_calm_code = 13 or gss_pq_felt_calm18_code = 14 then 3
when gss_pq_felt_calm_code = 14 or gss_pq_felt_calm18_code = 15 then 2
when gss_pq_felt_calm_code = 15 or gss_pq_felt_calm18_code = 16 then 1
else null end as HLT_MenHlth1
,case
when gss_pq_health_active_code = 11 then 6
when gss_pq_felt_energetic_code = 11 or gss_pq_health_active_code = 12 then 5
when gss_pq_felt_energetic_code = 12 or gss_pq_health_active_code = 13 then 4
when gss_pq_felt_energetic_code = 13 or gss_pq_health_active_code = 14 then 3
when gss_pq_felt_energetic_code = 14 or gss_pq_health_active_code = 15 then 2
when gss_pq_felt_energetic_code = 15 or gss_pq_health_active_code = 16 then 1
else null end as HLT_MenHlth2
,case
when gss_pq_health_cheerful_code = 11 then 6
when gss_pq_felt_depressed_code = 15 or gss_pq_health_cheerful_code = 12 then 5
when gss_pq_felt_depressed_code = 14 or gss_pq_health_cheerful_code = 13 then 4
when gss_pq_felt_depressed_code = 13 or gss_pq_health_cheerful_code = 14 then 3
when gss_pq_felt_depressed_code = 12 or gss_pq_health_cheerful_code = 15 then 2
when gss_pq_felt_depressed_code = 11 or gss_pq_health_cheerful_code = 16 then 1
else null end as HLT_MenHlth3
-----------SAFETY---------------
-----------------------
,case
when gss_pq_safe_night_hood_code = 11 then 5
when gss_pq_safe_night_hood_code = 12 then 4
when gss_pq_safe_night_hood_code = 13 then 3
when gss_pq_safe_night_hood_code = 14 then 2
when gss_pq_safe_night_hood_code = 15 then 1
else NULL end as SFT_Safe
,case 
when gss_pq_crimes_against_ind = 1 then 1   
when gss_pq_crimes_against_ind = 2 then 0 
else null end as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
,null as EST_MatWell1 --(0-31)
,case when gss_pq_material_wellbeing_code = 77 then null else gss_pq_material_wellbeing_code end as EST_MatWell2 -- (0-20)
,null as EST_MatWell3 --(0-17)
,case
when gss_pq_enough_inc_code = 11 then 1
when gss_pq_enough_inc_code = 12 then 0
when gss_pq_enough_inc_code = 13 then 0
when gss_pq_enough_inc_code = 14 then 0
else null end as EST_EnoughMon
 ----------------HOUSING--------------------------
-----------------------------------------------------
--NOTE: in 2014 and 2016 damp and mold problem asked in one double barreled question, 
--variable in 2018 needed to be reverse coded to match earlier years
, case 
when gss_pq_house_mold_code = 13 or gss_pq_cdm_house_damp_code = 11 then 3
when gss_pq_house_mold_code = 12 or gss_pq_cdm_house_damp_code = 12 then 2
when gss_pq_house_mold_code = 11 or gss_pq_cdm_house_damp_code = 13 then 1
else null end as HOU_Damp -- note this is both damp and mold
,case 
-- reverse code so 4 = cold is always a problem 
when gss_pq_house_cold_code = 11 then 4 
 when gss_pq_house_cold_code = 12 then 3
 when gss_pq_house_cold_code = 13 then 2
 when gss_pq_house_cold_code = 14 then 1
 else null end as HOU_Cold
 , case 
when gss_pq_HH_crowd_code = 1 then 1
when gss_pq_HH_crowd_code = 2 then 1
when gss_pq_HH_crowd_code = 3 then 0 
when gss_pq_HH_crowd_code = 4 then 0
when gss_pq_HH_crowd_code = 5 then 0
else null end as HOU_Crowded
 ----------------SOCIAL CONNECTEDNESS----------------------
-----------------------------------------------------
,case when gss_pq_trust_police_code = 88 then null when gss_pq_trust_police_code = 99 then null else gss_pq_trust_police_code end as SC_Trust_police
,case when gss_pq_trust_parliament_code = 88 then null when gss_pq_trust_parliament_code = 99 then null else gss_pq_trust_parliament_code end as SC_Trust_parl
,case when gss_pq_trust_health_code = 88 then null when gss_pq_trust_health_code = 99 then null else gss_pq_trust_health_code end as SC_Trust_health
,case when gss_pq_trust_media_code = 88 then null when gss_pq_trust_media_code = 99 then null else gss_pq_trust_media_code end as SC_Trust_media
,case when gss_pq_discriminated_code = 1 then 1 when gss_pq_discriminated_code = 2 then 0 else null end as SC_Discrim
,case 
when gss_pq_soc_feel_down_easy_hard = 11 then 5
when gss_pq_soc_feel_down_easy_hard = 12 then 4
when gss_pq_soc_feel_down_easy_hard = 13 then 3
when gss_pq_soc_feel_down_easy_hard = 14 then 2
when gss_pq_soc_feel_down_easy_hard = 15 then 1
else null end as SC_Support --only 2018
,case
when gss_pq_soc_contact_amt_fam_code = 11 then 3
when gss_pq_soc_contact_amt_fam_code = 12 then 2
when gss_pq_soc_contact_amt_fam_code = 13 then 1
else null end as SC_ConFam   --  only 2018
,case
when gss_pq_soc_contact_amt_frnd_code = 11 then 3
when gss_pq_soc_contact_amt_frnd_code = 12 then 2
when gss_pq_soc_contact_amt_frnd_code = 13 then 1
else null end as SC_ConFrd   --  only 2018
,case 
when gss_pq_time_lonely_code = 11 then 1
when gss_pq_time_lonely_code = 12 then 2
when gss_pq_time_lonely_code = 13 then 3
when gss_pq_time_lonely_code = 14 then 4
when gss_pq_time_lonely_code = 15 then 5
else null end as SC_Lonely 
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
,DEM_Region_org
,DEM_Region_8
,case
when gss_pq_lfs_dev= 1 then 1
when gss_pq_lfs_dev = 2 then 0
when gss_pq_lfs_dev = 3 then 0
when gss_pq_lfs_dev = 77 then null
else NULL end as EST_Emp1

FROM IDI_Clean_202206.gss_clean.gss_person  
-------------------------- FAMILY STRUCTURE AND REGION  --------------------------
------------------------------------------------------------------------------------
left join (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,case when DEM_Region_org = '99' then null else DEM_Region_org end as DEM_Region_org 
,DEM_Region_8
,case when father_mother>0 and partner_spouse>0 and dependent_children>0 then 1 else 0 end as FAM_CopDep
,case when (father_mother>0 and partner_spouse>0 and dependent_children=0) or (father_mother=0 and partner_spouse>0 and dependent_children=0) then 1 else 0 end as FAM_CopNoDep
,case when father_mother>0 and partner_spouse=0 and dependent_children>0 then 1 else 0 end as FAM_SoleDep
,case when (father_mother>0 and partner_spouse=0 and dependent_children=0) or (father_mother=0 and partner_spouse=0) then 1 else 0 end as FAM_Singles
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,partner_spouse
,father_mother
,DEM_Region_org
,DEM_Region_8
,sum(son_daughter_11+son_daughter_12+son_daughter_13+son_daughter_14+son_daughter_15+son_daughter_16+son_daughter_17+son_daughter_18+son_daughter_19+son_daughter_20+son_daughter_21+son_daughter_22+son_daughter_23+son_daughter_24) as dependent_children
from (
select snz_uid
,snz_gss_hhld_uid
,gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
,case when reln_11_father_mother = 11 then (case when age_person_11 < 18 then 1 else 0 end) else 0 end as son_daughter_11  
,case when reln_12_father_mother = 12 then (case when age_person_12 < 18 then 1 else 0 end) else 0 end as son_daughter_12 
,case when reln_13_father_mother = 13 then (case when age_person_13 < 18 then 1 else 0 end) else 0 end as son_daughter_13 
,case when reln_14_father_mother = 14 then (case when age_person_14 < 18 then 1 else 0 end) else 0 end as son_daughter_14 
,case when reln_15_father_mother = 15 then (case when age_person_15 < 18 then 1 else 0 end) else 0 end as son_daughter_15 
,case when reln_16_father_mother = 16 then (case when age_person_16 < 18 then 1 else 0 end) else 0 end as son_daughter_16 
,case when reln_17_father_mother = 17 then (case when age_person_17 < 18 then 1 else 0 end) else 0 end as son_daughter_17 
,case when reln_18_father_mother = 18 then (case when age_person_18 < 18 then 1 else 0 end) else 0 end as son_daughter_18
,case when reln_19_father_mother = 19 then (case when age_person_19 < 18 then 1 else 0 end) else 0 end as son_daughter_19
,case when reln_20_father_mother = 20 then (case when age_person_20 < 18 then 1 else 0 end) else 0 end as son_daughter_20 
,case when reln_21_father_mother = 21 then (case when age_person_21 < 18 then 1 else 0 end) else 0 end as son_daughter_21
,case when reln_22_father_mother = 22 then (case when age_person_22 < 18 then 1 else 0 end) else 0 end as son_daughter_22
,case when reln_23_father_mother = 23 then (case when age_person_23 < 18 then 1 else 0 end) else 0 end as son_daughter_23 
,case when reln_24_father_mother = 24 then (case when age_person_24 < 18 then 1 else 0 end) else 0 end as son_daughter_24
,sum(reln_11_father_mother+reln_12_father_mother+reln_13_father_mother+reln_14_father_mother+reln_15_father_mother+reln_16_father_mother+reln_17_father_mother+reln_18_father_mother+reln_19_father_mother+reln_20_father_mother+reln_21_father_mother+reln_22_father_mother+reln_23_father_mother+reln_24_father_mother) as father_mother
,sum(reln_11_spouse_partner+reln_12_spouse_partner+reln_13_spouse_partner+reln_14_spouse_partner+reln_15_spouse_partner+reln_16_spouse_partner+reln_17_spouse_partner+reln_18_spouse_partner+reln_19_spouse_partner+reln_20_spouse_partner+reln_21_spouse_partner+reln_22_spouse_partner+reln_23_spouse_partner+reln_24_spouse_partner) as partner_spouse
from ( 
select person.snz_uid
,person.snz_gss_hhld_uid
,person.gss_pq_collection_code
,DEM_Region_org
,case 
when DEM_Region_org = '01' or DEM_Region_org = '04' or DEM_Region_org = '05' or DEM_Region_org = '06' then 1 
when DEM_Region_org = '02' then 2
when DEM_Region_org = '03' then 3
when DEM_Region_org = '07' or DEM_Region_org = '08' then 4
when DEM_Region_org = '09' then 5
when DEM_Region_org = '16' or DEM_Region_org = '17' or DEM_Region_org = '18' or DEM_Region_org = '12' then 6
when DEM_Region_org = '13' then 7
when DEM_Region_org = '14' or DEM_Region_org = '15' then 8 
else null end as DEM_Region_8 
,case when gss_reln_relation_to_pers_11 = 11 then 1 else 0 end as reln_11_spouse_partner
,case when gss_reln_relation_to_pers_12 = 11 then 1 else 0 end as reln_12_spouse_partner
,case when gss_reln_relation_to_pers_13 = 11 then 1 else 0 end as reln_13_spouse_partner
,case when gss_reln_relation_to_pers_14 = 11 then 1 else 0 end as reln_14_spouse_partner
,case when gss_reln_relation_to_pers_15 = 11 then 1 else 0 end as reln_15_spouse_partner
,case when gss_reln_relation_to_pers_16 = 11 then 1 else 0 end as reln_16_spouse_partner
,case when gss_reln_relation_to_pers_17 = 11 then 1 else 0 end as reln_17_spouse_partner
,case when gss_reln_relation_to_pers_18 = 11 then 1 else 0 end as reln_18_spouse_partner
,case when gss_reln_relation_to_pers_19 = 11 then 1 else 0 end as reln_19_spouse_partner
,case when gss_reln_relation_to_pers_20 = 11 then 1 else 0 end as reln_20_spouse_partner
,case when gss_reln_relation_to_pers_21 = 11 then 1 else 0 end as reln_21_spouse_partner
,case when gss_reln_relation_to_pers_22 = 11 then 1 else 0 end as reln_22_spouse_partner
,case when gss_reln_relation_to_pers_23 = 11 then 1 else 0 end as reln_23_spouse_partner
,case when gss_reln_relation_to_pers_24 = 11 then 1 else 0 end as reln_24_spouse_partner

,case when gss_reln_relation_to_pers_11 = 13 then 11 else 0 end as reln_11_father_mother
,case when gss_reln_relation_to_pers_12 = 13 then 12 else 0 end as reln_12_father_mother
,case when gss_reln_relation_to_pers_13 = 13 then 13 else 0 end as reln_13_father_mother
,case when gss_reln_relation_to_pers_14 = 13 then 14 else 0 end as reln_14_father_mother
,case when gss_reln_relation_to_pers_15 = 13 then 15 else 0 end as reln_15_father_mother
,case when gss_reln_relation_to_pers_16 = 13 then 16 else 0 end as reln_16_father_mother
,case when gss_reln_relation_to_pers_17 = 13 then 17 else 0 end as reln_17_father_mother
,case when gss_reln_relation_to_pers_18 = 13 then 18 else 0 end as reln_18_father_mother
,case when gss_reln_relation_to_pers_19 = 13 then 19 else 0 end as reln_19_father_mother
,case when gss_reln_relation_to_pers_20 = 13 then 20 else 0 end as reln_20_father_mother
,case when gss_reln_relation_to_pers_21 = 13 then 21 else 0 end as reln_21_father_mother
,case when gss_reln_relation_to_pers_22 = 13 then 22 else 0 end as reln_22_father_mother
,case when gss_reln_relation_to_pers_23 = 13 then 23 else 0 end as reln_23_father_mother
,case when gss_reln_relation_to_pers_24 = 13 then 24 else 0 end as reln_24_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23
,age_person_24
from IDI_Clean_202206.gss_clean.gss_person person
left join IDI_Clean_202206.gss_clean.gss_relationship relationship
on person.snz_uid = relationship.snz_uid and person.gss_pq_collection_code = relationship.gss_reln_collection_code
left join (
select 
household.snz_gss_hhld_uid
,gss_reln_collection_code -- survey round identifier 
,gss_hq_regcouncil_dev as DEM_Region_org
,max(case when gss_reln_person_number = 11 then gss_hq_age_dev else null end) as age_person_11
,max(case when gss_reln_person_number = 12 then gss_hq_age_dev else null end) as age_person_12
,max(case when gss_reln_person_number = 13 then gss_hq_age_dev else null end) as age_person_13
,max(case when gss_reln_person_number = 14 then gss_hq_age_dev else null end) as age_person_14
,max(case when gss_reln_person_number = 15 then gss_hq_age_dev else null end) as age_person_15
,max(case when gss_reln_person_number = 16 then gss_hq_age_dev else null end) as age_person_16
,max(case when gss_reln_person_number = 17 then gss_hq_age_dev else null end) as age_person_17
,max(case when gss_reln_person_number = 18 then gss_hq_age_dev else null end) as age_person_18
,max(case when gss_reln_person_number = 19 then gss_hq_age_dev else null end) as age_person_19
,max(case when gss_reln_person_number = 20 then gss_hq_age_dev else null end) as age_person_20
,max(case when gss_reln_person_number = 21 then gss_hq_age_dev else null end) as age_person_21
,max(case when gss_reln_person_number = 22 then gss_hq_age_dev else null end) as age_person_22
,max(case when gss_reln_person_number = 23 then gss_hq_age_dev else null end) as age_person_23
,max(case when gss_reln_person_number = 24 then gss_hq_age_dev else null end) as age_person_24
from IDI_Clean_202206.gss_clean.gss_relationship relationship
left join IDI_Clean_202206.gss_clean.gss_household household
on (relationship.snz_uid = household.snz_uid and relationship.gss_reln_collection_code = household.gss_hq_collection_code)
left join IDI_Clean_202206.gss_clean.gss_person person
on person.snz_uid = household.snz_uid and person.gss_pq_collection_code = household.gss_hq_collection_code
group by household.snz_gss_hhld_uid,gss_reln_collection_code, gss_hq_regcouncil_dev) joined
on person.snz_gss_hhld_uid = joined.snz_gss_hhld_uid) group1
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code
,DEM_Region_org
,DEM_Region_8
,reln_11_father_mother
,reln_12_father_mother
,reln_13_father_mother
,reln_14_father_mother
,reln_15_father_mother
,reln_16_father_mother
,reln_17_father_mother
,reln_18_father_mother
,reln_19_father_mother
,reln_20_father_mother
,reln_21_father_mother
,reln_22_father_mother
,reln_23_father_mother
,reln_24_father_mother
,age_person_11
,age_person_12
,age_person_13
,age_person_14
,age_person_15
,age_person_16
,age_person_17
,age_person_18
,age_person_19
,age_person_20
,age_person_21
,age_person_22
,age_person_23
,age_person_24) group2
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother,DEM_Region_org,DEM_Region_8) group3
group by snz_uid, snz_gss_hhld_uid, gss_pq_collection_code, partner_spouse, father_mother, dependent_children,DEM_Region_org,DEM_Region_8) all_data
on gss_person.snz_gss_hhld_uid = all_data.snz_gss_hhld_uid and gss_person.gss_pq_collection_code = all_data.gss_pq_collection_code


-- This is the end of united GSS waves (it is saved into a temporary table: #gss_all_temp)


-------------------------------------------------------------------
-------------------------------------------------------------------
-------------------------------------------------------------------
-------------------------------------------------------------------
--PREPARE HLFS DATA FROM FOUR QUARTERS 



-- Note: Some variables are in the HLFS Supplementary data while others are in the main HLFS data. 
-- Hence, we need to join these two at each quarter before uniting the four quarters. 

-- FIRST QUARTER

-- Step 1: 
-- select variables from Supplementary data and main data 
-- join them and save data into a temporary table 


create table #hlfs1
(
hl_idsup	int
,hl_hhidsup	int
,qrt_num	int
,interview_date	date
,survey_yr	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,snz_uid	int
,hlfs_id	int
,hh_id	int
,gss_id int
,p_id	int
,qrt_n	int
,hlfs_urd_fam_num_dep_nbr int
,hlfs_urd_fam_num_indep_nbr int 
,hlfs_urd_fam_with_partner_ind int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,hlfs_qrt int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
)

insert into #hlfs1

SELECT  * 
FROM(
SELECT  
snz_hlfs_uid as hl_idsup
,snz_hlfs_hhld_uid as hl_hhidsup
,quarter as qrt_num
,SQD_fSQInterviewDate as interview_date
, YEAR(SQD_fSQInterviewDate) as survey_yr
, person_code as personID
-----------DEMOGRAPHICS---------------
-----------------------
,case when DVSex = 1 then 0 when DVSex = 2 then 1 else null end as DEM_Gend --0=man,1=woman
,DVAge  as DEM_Age
,DOB_month as DEM_birth_month
,DOB_year as DEM_birth_year
,EthEuropean as DEM_Euro
,EthMaori as DEM_Maori
,EthPacific as DEM_Pacific
,EthAsian as DEM_Asian
,EthMELAA as DEM_MELAA
,EthOther as DEM_Other
,case when DVDisability =1 then 1 when DVDisability = 2 then 0 else null end as DEM_Disabled
,case when  DVCOB = 1201 then 0 else 1 end as DEM_Migrant 
--Subjective wellbeing
-----------------------
,null as SW_Identity
, case 
when PWB_qFeelAboutLifeScale =0 then 1
when PWB_qFeelAboutLifeScale =1 then 1
when PWB_qFeelAboutLifeScale =2 then 1
when PWB_qFeelAboutLifeScale =3 then 1
when PWB_qFeelAboutLifeScale =4 then 2
when PWB_qFeelAboutLifeScale =5 then 3
when PWB_qFeelAboutLifeScale =6 then 4 
when PWB_qFeelAboutLifeScale =7 then 4
when PWB_qFeelAboutLifeScale =8 then 4
when PWB_qFeelAboutLifeScale =9 then 5 
when PWB_qFeelAboutLifeScale =10 then 5
else null end as SW_LifeSat
,case
when PWB_qFamWellbeing =11 then null
when PWB_qFamWellbeing =12 then null
when PWB_qFamWellbeing =88 then null
when PWB_qFamWellbeing =99 then null else PWB_qFamWellbeing end as SW_FamWell
-----------HEALTH---------------
-----------------------
,case 
when PWB_qHealthExcellentPoor = 11 then 5
when PWB_qHealthExcellentPoor = 12 then 4
when PWB_qHealthExcellentPoor = 13 then 3
when PWB_qHealthExcellentPoor = 14 then 2
when PWB_qHealthExcellentPoor = 15 then 1
else null end as HLT_GenHlth
,case
when PWB_qCalm = 11 then 6
when PWB_qCalm = 12 then 5
when PWB_qCalm = 13 then 4
when PWB_qCalm = 14 then 3
when PWB_qCalm = 15 then 2
when PWB_qCalm = 16 then 1
else null end as HLT_MenHlth1 --only hlfs 0820
,case
when PWB_qActive = 11 then 6
when PWB_qActive = 12 then 5
when PWB_qActive = 13 then 4
when PWB_qActive = 14 then 3
when PWB_qActive = 15 then 2
when PWB_qActive = 16 then 1
else null end as HLT_MenHlth2 --only hlfs 0820
,case
when PWB_qCheerful = 11 then 6
when PWB_qCheerful = 12 then 5
when PWB_qCheerful = 13 then 4
when PWB_qCheerful = 14 then 3
when PWB_qCheerful = 15 then 2
when PWB_qCheerful = 16 then 1
else null end as HLT_MenHlth3 --only hlfs 0820
-----------SAFETY---------------
-----------------------
,case
when PWB_qSafeNightHood = 11 then 5
when PWB_qSafeNightHood = 12 then 4
when PWB_qSafeNightHood = 13 then 3
when PWB_qSafeNightHood = 14 then 2
when PWB_qSafeNightHood = 15 then 1
else null end as SFT_Safe
,null  as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
,null as EST_MatWell1
,null as EST_MatWell2 -- from 0 to 20, 77
, case when Dep17 = 77 then null else Dep17 end as EST_MatWell3 --(0-17)
,case
when MHS_qEnoughIncome = 11 then 1
when MHS_qEnoughIncome = 12 then 0
when MHS_qEnoughIncome = 13 then 0
when MHS_qEnoughIncome = 14 then 0
else null end as EST_EnoughMon
 ----------------HOUSING--------------------------
-----------------------------------------------------
--NOTE: in HLFS damp and mold problem asked in one question, 
, case 
when HCQ_qDampOrMould = 13  then 3
when HCQ_qDampOrMould = 12  then 2
when HCQ_qDampOrMould = 11  then 1
else null end as HOU_Damp
,case 
 when HCQ_qKeepingWarm = 13 then 3
 when HCQ_qKeepingWarm = 12 then 2
 when HCQ_qKeepingWarm = 11 then 1
 else null end as HOU_Cold
,null as HOU_Crowded
 ----------------SOCIAL CONNECTEDNESS----------------------
-----------------------------------------------------
,case when PWB_qTrustPol = 88 then null when PWB_qTrustPol = 99 then null else PWB_qTrustPol end as SC_Trust_police
,case when PWB_qTrustParl = 88 then null when PWB_qTrustParl = 99 then null else PWB_qTrustParl end as SC_Trust_parl
,case when PWB_qTrustHlth = 88 then null when PWB_qTrustHlth = 99 then null else PWB_qTrustHlth end as SC_Trust_health
,case when PWB_qTrustMed = 88 then null when PWB_qTrustMed = 99 then null else PWB_qTrustMed end as SC_Trust_media
,case when PWB_qDiscriminated = 1 then 1 when PWB_qDiscriminated = 2 then 0 else null end as SC_Discrim
,null  as SC_Support 
, null as SC_ConFam   
,null as SC_ConFrd  
,case 
when PWB_qTimeLonely = 11 then 1
when PWB_qTimeLonely = 12 then 2
when PWB_qTimeLonely = 13 then 3
when PWB_qTimeLonely = 14 then 4
when PWB_qTimeLonely = 15 then 5
else null end as SC_Lonely
FROM 
[IDI_Adhoc].[clean_read_HLFS].hlfs_wellbeing_202008) as sup
 ---------------- FAMILY STRUCTURE AND REGION ----------------------
--------------------------------------------------------------------
left join(
select 
snz_uid
,snz_hlfs_uid as hlfs_id
,snz_hlfs_hhld_uid as hh_id
,null as gss_id
,hlfs_urd_person_nbr as p_id
,hlfs_urd_quarter_nbr as qrt_n
,hlfs_urd_fam_num_dep_nbr
,hlfs_urd_fam_num_indep_nbr
,hlfs_urd_fam_with_partner_ind
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_CopDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_CopNoDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_SoleDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_Singles
,case when hlfs_urd_quarter_nbr = 139 then 1 else hlfs_urd_quarter_nbr end as hlfs_qrt
,hlfs_urd_region_code as DEM_Region_org
,case
when hlfs_urd_region_code = '01' or hlfs_urd_region_code = '04' or hlfs_urd_region_code = '05' then 1 
when hlfs_urd_region_code = '02' then 2
when hlfs_urd_region_code = '03' then 3
when hlfs_urd_region_code = '06' or hlfs_urd_region_code = '07' then 4
when hlfs_urd_region_code = '08' then 5
when hlfs_urd_region_code = '09' then 6
when hlfs_urd_region_code = '10' then 7
when hlfs_urd_region_code = '11' or hlfs_urd_region_code = '12' then 8 
else null end as DEM_Region_8 
 -----------EMPLOYMENT-------------------------------
-----------------------------------------------------
,case
when  hlfs_urd_lfs_code= 1 then 1
when  hlfs_urd_lfs_code= 2 then 0
when  hlfs_urd_lfs_code= 3 then 0
when  hlfs_urd_lfs_code = 9 then null
else NULL end as EST_Emp1
from IDI_Clean_202206.hlfs_clean.data) as hl1
on sup.hl_idsup = hl1.hlfs_id
and sup.hl_hhidsup = hl1.hh_id
and sup.personID = hl1.p_id
and sup.qrt_num = hl1.qrt_n

--verify data:
select * from #hlfs1

-- Step 2: 
-- drop variables that we do not need
-- rename some variables 
-- change the order of variables to match the order of variables in the GSS table
-- save it into another temporary table 

create table #hlfs1b
(
snz_uid	int
,hh_id	int
, gss_id int
,hlfs_id	int
,hlfs_qrt	int
,interview_date	date
,survey_yr	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
)
insert into #hlfs1b
select 
snz_uid
,hh_id
,gss_id
,hlfs_id
,hlfs_qrt
,interview_date	
,survey_yr	
,personID	
,DEM_Gend	
,DEM_Age	
,DEM_birth_month	
,DEM_birth_year	
,DEM_Euro	
,DEM_Maori	
,DEM_Pacific	
,DEM_Asian	
,DEM_MELAA	
,DEM_Other	
,DEM_Disabled	
,DEM_Migrant	
,SW_Identity	
,SW_LifeSat	
,SW_FamWell	
,HLT_GenHlth	
,HLT_MenHlth1	
,HLT_MenHlth2	
,HLT_MenHlth3	
,SFT_Safe	
,SFT_Victim	
,EST_MatWell1	
,EST_MatWell2	
,EST_MatWell3	
,EST_EnoughMon
,HOU_Damp	
,HOU_Cold	
,HOU_Crowded	
,SC_Trust_police	
,SC_Trust_parl	
,SC_Trust_health	
,SC_Trust_media	
,SC_Discrim	
,SC_Support	
,SC_ConFam	
,SC_ConFrd	
,SC_Lonely	
,FAM_CopDep 
,FAM_CopNoDep 
,FAM_SoleDep 
,FAM_Singles 
,DEM_Region_org
,DEM_Region_8
,EST_Emp1
from #hlfs1

--verify data: 
select * from #hlfs1b

-- this is the end of the first quarter (it is saved into a temporary table called #hlfs1b)
-- now we repeate this procedure for each quarter 

-- SECOND QUARTER


-- Step 1
create table #hlfs2
(

hl_idsup	int
,hl_hhidsup	int
,qrt_num	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,snz_uid	int
,interview_date	date
,survey_yr	int
,hlfs_id	int
,hh_id	int
,gss_id int
,p_id	int
,qrt_n	int
,hlfs_urd_fam_num_dep_nbr int
,hlfs_urd_fam_num_indep_nbr int 
,hlfs_urd_fam_with_partner_ind int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,hlfs_qrt	int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
)
insert into #hlfs2

SELECT * 
FROM(
SELECT  
snz_hlfs_uid as hl_idsup
,snz_hlfs_hhld_uid as hl_hhidsup
,quarter as qrt_num
, person_code as personID
-----------DEMOGRAPHICS---------------
-----------------------
,case when DVSex = 1 then 0 when DVSex = 2 then 1 else null end as DEM_Gend --0=man,1=woman
,DVAge  as DEM_Age
,DOB_month as DEM_birth_month
,DOB_year as DEM_birth_year
,EthEuropean as DEM_Euro
,EthMaori as DEM_Maori
,EthPacific as DEM_Pacific
,EthAsian as DEM_Asian
,EthMELAA as DEM_MELAA
,EthOther as DEM_Other
,null as DEM_Disabled
,case when  DVCOB = 1201 then 0 else 1 end as DEM_Migrant
-------------SUBJECTIVE WELLEBING---------------------
------------------------------------------------
,null as SW_Identity
, case 
when PWB_qFeelAboutLifeScale =0 then 1
when PWB_qFeelAboutLifeScale =1 then 1
when PWB_qFeelAboutLifeScale =2 then 1
when PWB_qFeelAboutLifeScale =3 then 1
when PWB_qFeelAboutLifeScale =4 then 2
when PWB_qFeelAboutLifeScale =5 then 3
when PWB_qFeelAboutLifeScale =6 then 4 
when PWB_qFeelAboutLifeScale =7 then 4
when PWB_qFeelAboutLifeScale =8 then 4
when PWB_qFeelAboutLifeScale =9 then 5 
when PWB_qFeelAboutLifeScale =10 then 5
else null end as SW_LifeSat
,case
when PWB_qFamWellbeing =11 then null
when PWB_qFamWellbeing =12 then null
when PWB_qFamWellbeing =88 then null
when PWB_qFamWellbeing =99 then null else PWB_qFamWellbeing end as SW_FamWell
-----------HEALTH---------------
-----------------------
,case 
when PWB_qHealthExcellentPoor = 11 then 5
when PWB_qHealthExcellentPoor = 12 then 4
when PWB_qHealthExcellentPoor = 13 then 3
when PWB_qHealthExcellentPoor = 14 then 2
when PWB_qHealthExcellentPoor = 15 then 1
else null end as HLT_GenHlth
, null as HLT_MenHlth1
,null as HLT_MenHlth2 
,null as HLT_MenHlth3 
-----------SAFETY---------------
-----------------------
,null as SFT_Safe
,null  as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
,null as EST_MatWell1
,null as EST_MatWell2 -- from 0 to 20, 77
, case when Dep17 = 77 then null else Dep17 end as EST_MatWell3 --(0-17)
,case
when MHS_qEnoughIncome = 11 then 1
when MHS_qEnoughIncome = 12 then 0
when MHS_qEnoughIncome = 13 then 0
when MHS_qEnoughIncome = 14 then 0
else null end as EST_EnoughMon
 ----------------HOUSING--------------------------
-----------------------------------------------------
--NOTE: in hlfs damp and mold problem asked in one questions, 
, case 
when HCQ_qDampOrMould = 13  then 3
when HCQ_qDampOrMould = 12  then 2
when HCQ_qDampOrMould = 11  then 1
else null end as HOU_Damp
,case 
 when HCQ_qKeepingWarm = 13 then 3
 when HCQ_qKeepingWarm = 12 then 2
 when HCQ_qKeepingWarm = 11 then 1
 else null end as HOU_Cold
,null as HOU_Crowded
 ----------------SOCIAL CONNECTEDNESS----------------------
-----------------------------------------------------
,case when PWB_qTrustPol = 88 then null when PWB_qTrustPol = 99 then null else PWB_qTrustPol end as SC_Trust_police
,case when PWB_qTrustParl = 88 then null when PWB_qTrustParl = 99 then null else PWB_qTrustParl end as SC_Trust_parl
,case when PWB_qTrustHlth = 88 then null when PWB_qTrustHlth = 99 then null else PWB_qTrustHlth end as SC_Trust_health
,case when PWB_qTrustMed = 88 then null when PWB_qTrustMed = 99 then null else PWB_qTrustMed end as SC_Trust_media
,case when PWB_qDiscriminated = 1 then 1 when PWB_qDiscriminated = 2 then 0 else null end as SC_Discrim
,null  as SC_Support 
, null as SC_ConFam   
,null as SC_ConFrd  
,case 
when PWB_qTimeLonely = 11 then 1
when PWB_qTimeLonely = 12 then 2
when PWB_qTimeLonely = 13 then 3
when PWB_qTimeLonely = 14 then 4
when PWB_qTimeLonely = 15 then 5
else null end as SC_Lonely
FROM 
[IDI_Adhoc].[clean_read_HLFS].hlfs_wellbeing_202011) as sup
 ---------------- FAMILY STRUCTURE AND REGION ----------------------
--------------------------------------------------------------------
left join(
select 
snz_uid
,hlfs_urd_interview_date as interview_date
,YEAR(hlfs_urd_interview_date) as survey_yr
,snz_hlfs_uid as hlfs_id
,snz_hlfs_hhld_uid as hh_id
, null as gss_id
,hlfs_urd_person_nbr as p_id
,hlfs_urd_quarter_nbr as qrt_n
,hlfs_urd_fam_num_dep_nbr
,hlfs_urd_fam_num_indep_nbr
,hlfs_urd_fam_with_partner_ind
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_CopDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_CopNoDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_SoleDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_Singles
,case when hlfs_urd_quarter_nbr = 140 then 2 else hlfs_urd_quarter_nbr end as hlfs_qrt
,hlfs_urd_region_code as DEM_Region_org
,case
when hlfs_urd_region_code = '01' or hlfs_urd_region_code = '04' or hlfs_urd_region_code = '05' then 1 
when hlfs_urd_region_code = '02' then 2
when hlfs_urd_region_code = '03' then 3
when hlfs_urd_region_code = '06' or hlfs_urd_region_code = '07' then 4
when hlfs_urd_region_code = '08' then 5
when hlfs_urd_region_code = '09' then 6
when hlfs_urd_region_code = '10' then 7
when hlfs_urd_region_code = '11' or hlfs_urd_region_code = '12' then 8 
else null end as DEM_Region_8 
,case
when  hlfs_urd_lfs_code= 1 then 1
when  hlfs_urd_lfs_code= 2 then 0
when  hlfs_urd_lfs_code= 3 then 0
when  hlfs_urd_lfs_code = 9 then null
else NULL end as EST_Emp1
from IDI_Clean_202206.hlfs_clean.data ) as hl1
on sup.hl_idsup = hl1.hlfs_id
and sup.hl_hhidsup = hl1.hh_id
and sup.personID = hl1.p_id
and sup.qrt_num = hl1.qrt_n;

-- verify data:
select * from #hlfs2


-- Step 2
create table #hlfs2b
(
snz_uid	int
,hh_id	int
, gss_id int
,hlfs_id	int
,hlfs_qrt	int
,interview_date	date
,survey_yr	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
)
insert into #hlfs2b
select 
snz_uid	
,hh_id	
, gss_id 
,hlfs_id	
,hlfs_qrt	
,interview_date	
,survey_yr	
,personID	
,DEM_Gend	
,DEM_Age	
,DEM_birth_month	
,DEM_birth_year	
,DEM_Euro	
,DEM_Maori	
,DEM_Pacific	
,DEM_Asian	
,DEM_MELAA	
,DEM_Other	
,DEM_Disabled	
,DEM_Migrant	
,SW_Identity	
,SW_LifeSat	
,SW_FamWell	
,HLT_GenHlth	
,HLT_MenHlth1	
,HLT_MenHlth2	
,HLT_MenHlth3	
,SFT_Safe	
,SFT_Victim	
,EST_MatWell1	
,EST_MatWell2	
,EST_MatWell3	
,EST_EnoughMon
,HOU_Damp	
,HOU_Cold	
,HOU_Crowded	
,SC_Trust_police	
,SC_Trust_parl	
,SC_Trust_health	
,SC_Trust_media	
,SC_Discrim	
,SC_Support	
,SC_ConFam	
,SC_ConFrd	
,SC_Lonely	
,FAM_CopDep 
,FAM_CopNoDep 
,FAM_SoleDep 
,FAM_Singles 
,DEM_Region_org
,DEM_Region_8
,EST_Emp1
from #hlfs2

--verify data:
select * from #hlfs2b


-- THIRD QUARTER

-- Step 1
create table #hlfs3
(
hl_idsup	int
,hl_hhidsup	int
,qrt_num	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,snz_uid	int
,interview_date	date
,survey_yr	int
,hlfs_id	int
,hh_id	int
,gss_id int
,p_id	int
,qrt_n	int
,hlfs_urd_fam_num_dep_nbr int
,hlfs_urd_fam_num_indep_nbr int 
,hlfs_urd_fam_with_partner_ind int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,hlfs_qrt	int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
)
insert into #hlfs3

SELECT   * 
FROM(
SELECT  
snz_hlfs_uid as hl_idsup
,snz_hlfs_hhld_uid as hl_hhidsup
,quarter_nbr as qrt_num
--,SQD_fSQInterviewDate as interview_date
, person_code as personID
-----------DEMOGRAPHICS---------------
-----------------------
,case when DVSex = 1 then 0 when DVSex = 2 then 1 else null end as DEM_Gend --0=man,1=woman
,DVAge  as DEM_Age
,DOB_month as DEM_birth_month
,DOB_year as DEM_birth_year
,EthEuropean as DEM_Euro
,EthMaori as DEM_Maori
,EthPacific as DEM_Pacific
,EthAsian as DEM_Asian
,EthMELAA as DEM_MELAA
,EthOther as DEM_Other
,case when DVDisability =1 then 1 when DVDisability = 2 then 0 else null end as DEM_Disabled
,case when  DVCOB = 1201 then 0 else 1 end as DEM_Migrant
---------SUBJECTIVE WELLBEING-------
-----------------------------
,null as SW_Identity
, case 
when PWB_qFeelAboutLifeScale =0 then 1
when PWB_qFeelAboutLifeScale =1 then 1
when PWB_qFeelAboutLifeScale =2 then 1
when PWB_qFeelAboutLifeScale =3 then 1
when PWB_qFeelAboutLifeScale =4 then 2
when PWB_qFeelAboutLifeScale =5 then 3
when PWB_qFeelAboutLifeScale =6 then 4 
when PWB_qFeelAboutLifeScale =7 then 4
when PWB_qFeelAboutLifeScale =8 then 4
when PWB_qFeelAboutLifeScale =9 then 5 
when PWB_qFeelAboutLifeScale =10 then 5
else null end as SW_LifeSat
,case
when PWB_qFamWellbeing =11 then null
when PWB_qFamWellbeing =12 then null
when PWB_qFamWellbeing =88 then null
when PWB_qFamWellbeing =99 then null else PWB_qFamWellbeing end as SW_FamWell
-----------HEALTH---------------
-----------------------
,case 
when PWB_qHealthExcellentPoor = 11 then 5
when PWB_qHealthExcellentPoor = 12 then 4
when PWB_qHealthExcellentPoor = 13 then 3
when PWB_qHealthExcellentPoor = 14 then 2
when PWB_qHealthExcellentPoor = 15 then 1
else null end as HLT_GenHlth
, null as HLT_MenHlth1
,null as HLT_MenHlth2 
,null as HLT_MenHlth3 
-----------SAFETY---------------
-----------------------
,null as SFT_Safe
,null  as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
,null as EST_MatWell1
,null as EST_MatWell2 -- from 0 to 20, 77
, case when Dep17 = 77 then null else Dep17 end as EST_MatWell3 --(0-17)
,case
when MHS_qEnoughIncome = 11 then 1
when MHS_qEnoughIncome = 12 then 0
when MHS_qEnoughIncome = 13 then 0
when MHS_qEnoughIncome = 14 then 0
else null end as EST_EnoughMon
 ----------------HOUSING--------------------------
-----------------------------------------------------
--NOTE: in hlfs damp and mold problem asked in one questions, 
, case 
when HCQ_qDampOrMould = 13  then 3
when HCQ_qDampOrMould = 12  then 2
when HCQ_qDampOrMould = 11  then 1
else null end as HOU_Damp
,case 
 when HCQ_qKeepingWarm = 13 then 3
 when HCQ_qKeepingWarm = 12 then 2
 when HCQ_qKeepingWarm = 11 then 1
 else null end as HOU_Cold
,null as HOU_Crowded
 ----------------SOCIAL CONNECTEDNESS----------------------
-----------------------------------------------------
,case when PWB_qTrustPol = 88 then null when PWB_qTrustPol = 99 then null else PWB_qTrustPol end as SC_Trust_police
,case when PWB_qTrustParl = 88 then null when PWB_qTrustParl = 99 then null else PWB_qTrustParl end as SC_Trust_parl
,case when PWB_qTrustHlth = 88 then null when PWB_qTrustHlth = 99 then null else PWB_qTrustHlth end as SC_Trust_health
,case when PWB_qTrustMed = 88 then null when PWB_qTrustMed = 99 then null else PWB_qTrustMed end as SC_Trust_media
,case when PWB_qDiscriminated = 1 then 1 when PWB_qDiscriminated = 2 then 0 else null end as SC_Discrim
,null  as SC_Support 
, null as SC_ConFam   
,null as SC_ConFrd   
,case 
when PWB_qTimeLonely = 11 then 1
when PWB_qTimeLonely = 12 then 2
when PWB_qTimeLonely = 13 then 3
when PWB_qTimeLonely = 14 then 4
when PWB_qTimeLonely = 15 then 5
else null end as SC_Lonely
FROM 
[IDI_Adhoc].[clean_read_HLFS].hlfs_wellbeing_202102) as sup
 ---------------- FAMILY STRUCTURE AND REGION ----------------------
--------------------------------------------------------------------
left join(
select 
snz_uid
,hlfs_urd_interview_date as interview_date
,YEAR(hlfs_urd_interview_date) as survey_yr
,snz_hlfs_uid as hlfs_id
,snz_hlfs_hhld_uid as hh_id
, null as gss_id
,hlfs_urd_person_nbr as p_id
,hlfs_urd_quarter_nbr as qrt_n
,hlfs_urd_fam_num_dep_nbr
,hlfs_urd_fam_num_indep_nbr
,hlfs_urd_fam_with_partner_ind
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_CopDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_CopNoDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_SoleDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_Singles
,case when hlfs_urd_quarter_nbr = 141 then 3 else hlfs_urd_quarter_nbr end as hlfs_qrt
,hlfs_urd_region_code as DEM_Region_org
,case
when hlfs_urd_region_code = '01' or hlfs_urd_region_code = '04' or hlfs_urd_region_code = '05' then 1 
when hlfs_urd_region_code = '02' then 2
when hlfs_urd_region_code = '03' then 3
when hlfs_urd_region_code = '06' or hlfs_urd_region_code = '07' then 4
when hlfs_urd_region_code = '08' then 5
when hlfs_urd_region_code = '09' then 6
when hlfs_urd_region_code = '10' then 7
when hlfs_urd_region_code = '11' or hlfs_urd_region_code = '12' then 8 
else null end as DEM_Region_8 
,case 
when  hlfs_urd_lfs_code= 1 then 1
when  hlfs_urd_lfs_code= 2 then 0
when  hlfs_urd_lfs_code= 3 then 0
when  hlfs_urd_lfs_code = 9 then null
else NULL end as EST_Emp1
from IDI_Clean_202206.hlfs_clean.data ) as hl1
on sup.hl_idsup = hl1.hlfs_id
and sup.hl_hhidsup = hl1.hh_id
and sup.personID = hl1.p_id
and sup.qrt_num = hl1.qrt_n;

select * from #hlfs3

-- Step 2 
create table #hlfs3b
(
snz_uid	int
,hh_id	int
, gss_id int
,hlfs_id	int
,hlfs_qrt	int
,interview_date	date
,survey_yr	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
)
insert into #hlfs3b
select 
snz_uid	
,hh_id	
,gss_id 
,hlfs_id	
,hlfs_qrt	
,interview_date	
,survey_yr	
,personID	
,DEM_Gend	
,DEM_Age	
,DEM_birth_month	
,DEM_birth_year	
,DEM_Euro	
,DEM_Maori	
,DEM_Pacific	
,DEM_Asian	
,DEM_MELAA	
,DEM_Other	
,DEM_Disabled	
,DEM_Migrant	
,SW_Identity	
,SW_LifeSat	
,SW_FamWell	
,HLT_GenHlth	
,HLT_MenHlth1	
,HLT_MenHlth2	
,HLT_MenHlth3	
,SFT_Safe	
,SFT_Victim	
,EST_MatWell1	
,EST_MatWell2	
,EST_MatWell3	
,EST_EnoughMon	
,HOU_Damp	
,HOU_Cold	
,HOU_Crowded	
,SC_Trust_police	
,SC_Trust_parl	
,SC_Trust_health	
,SC_Trust_media	
,SC_Discrim	
,SC_Support	
,SC_ConFam	
,SC_ConFrd	
,SC_Lonely	
,FAM_CopDep 
,FAM_CopNoDep 
,FAM_SoleDep 
,FAM_Singles 
,DEM_Region_org
,DEM_Region_8 
,EST_Emp1
from #hlfs3

--verify data: 
select * from #hlfs3b

-- FORTH QUARTER

-- Step 1
create table #hlfs4
(
hl_idsup	int
,hl_hhidsup	int
,qrt_num	int
,interview_date	date
,survey_yr	int
,personID	int
,DEM_Gend	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,snz_uid	int
,hlfs_id	int
,hh_id	int
,gss_id int
,p_id	int
,qrt_n	int
,hlfs_urd_fam_num_dep_nbr int
,hlfs_urd_fam_num_indep_nbr int 
,hlfs_urd_fam_with_partner_ind int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,hlfs_qrt	int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
,DEM_Age	int
)
insert into #hlfs4

SELECT   * 
FROM(
SELECT  
snz_hlfs_uid as hl_idsup
,snz_hlfs_hhld_uid as hl_hhidsup
,quarter_nbr as qrt_num
,SQD_fSQInterviewDate as interview_date
, YEAR(SQD_fSQInterviewDate) as survey_yr
, person_code as personID
-----------DEMOGRAPHICS---------------
-----------------------
,case when DVSex = 1 then 0 when DVSex = 2 then 1 else null end as DEM_Gend --0=man,1=woman
--,DVAge  as DEM_Age
,DOB_month as DEM_birth_month
,DOB_year as DEM_birth_year
,EthEuropean as DEM_Euro
,EthMaori as DEM_Maori
,EthPacific as DEM_Pacific
,EthAsian as DEM_Asian
,EthMELAA as DEM_MELAA
,EthOther as DEM_Other
,null as DEM_Disabled
,case when  DVCOB = 1201 then 0 else 1 end as DEM_Migrant
---------SUBJECTIVE WELLBEING----------------
------------------------------
,null as SW_Identity
, case 
when PWB_qFeelAboutLifeScale =0 then 1
when PWB_qFeelAboutLifeScale =1 then 1
when PWB_qFeelAboutLifeScale =2 then 1
when PWB_qFeelAboutLifeScale =3 then 1
when PWB_qFeelAboutLifeScale =4 then 2
when PWB_qFeelAboutLifeScale =5 then 3
when PWB_qFeelAboutLifeScale =6 then 4 
when PWB_qFeelAboutLifeScale =7 then 4
when PWB_qFeelAboutLifeScale =8 then 4
when PWB_qFeelAboutLifeScale =9 then 5 
when PWB_qFeelAboutLifeScale =10 then 5
else null end as SW_LifeSat
,case
when PWB_qFamWellbeing =11 then null
when PWB_qFamWellbeing =12 then null
when PWB_qFamWellbeing =88 then null
when PWB_qFamWellbeing =99 then null else PWB_qFamWellbeing end as SW_FamWell
-----------HEALTH---------------
-----------------------
,case 
when PWB_qHealthExcellentPoor = 11 then 5
when PWB_qHealthExcellentPoor = 12 then 4
when PWB_qHealthExcellentPoor = 13 then 3
when PWB_qHealthExcellentPoor = 14 then 2
when PWB_qHealthExcellentPoor = 15 then 1
else null end as HLT_GenHlth
,null as HLT_MenHlth1
,null as HLT_MenHlth2 
,null as HLT_MenHlth3 
-----------SAFETY---------------
-----------------------
,null as SFT_Safe
,null  as SFT_Victim 
 -----------ECONOMIC STANDARD OF LIVING---------------
-----------------------------------------------------
,null as EST_MatWell1
,null as EST_MatWell2 -- from 0 to 20, 77
, case when Dep17 = 77 then null else Dep17 end as EST_MatWell3 --(0-17)
,case
when MHS_qEnoughIncome = 11 then 1
when MHS_qEnoughIncome = 12 then 0
when MHS_qEnoughIncome = 13 then 0
when MHS_qEnoughIncome = 14 then 0
else null end as EST_EnoughMon
 ----------------HOUSING--------------------------
-----------------------------------------------------
--NOTE: in hlfs damp and mold problem asked in one questions, 
, case 
when HCQ_qDampOrMould = 13  then 3
when HCQ_qDampOrMould = 12  then 2
when HCQ_qDampOrMould = 11  then 1
else null end as HOU_Damp
,case 
 when HCQ_qKeepingWarm = 13 then 3
 when HCQ_qKeepingWarm = 12 then 2
 when HCQ_qKeepingWarm = 11 then 1
 else null end as HOU_Cold
,null as HOU_Crowded
 ----------------SOCIAL CONNECTEDNESS----------------------
-----------------------------------------------------
,case when PWB_qTrustPol = 88 then null when PWB_qTrustPol = 99 then null else PWB_qTrustPol end as SC_Trust_police
,case when PWB_qTrustParl = 88 then null when PWB_qTrustParl = 99 then null else PWB_qTrustParl end as SC_Trust_parl
,case when PWB_qTrustHlth = 88 then null when PWB_qTrustHlth = 99 then null else PWB_qTrustHlth end as SC_Trust_health
,case when PWB_qTrustMed = 88 then null when PWB_qTrustMed = 99 then null else PWB_qTrustMed end as SC_Trust_media
,case when PWB_qDiscriminated = 1 then 1 when PWB_qDiscriminated = 2 then 0 else null end as SC_Discrim
,null  as SC_Support 
, null as SC_ConFam   
,null as SC_ConFrd  
,case 
when PWB_qTimeLonely = 11 then 1
when PWB_qTimeLonely = 12 then 2
when PWB_qTimeLonely = 13 then 3
when PWB_qTimeLonely = 14 then 4
when PWB_qTimeLonely = 15 then 5
else null end as SC_Lonely
FROM 
[IDI_Adhoc].[clean_read_HLFS].hlfs_wellbeing_202105) as sup
 ---------------- FAMILY STRUCTURE AND REGION ----------------------
--------------------------------------------------------------------
left join(
select 
snz_uid
,snz_hlfs_uid as hlfs_id
,snz_hlfs_hhld_uid as hh_id
,null as gss_id
,hlfs_urd_person_nbr as p_id
,hlfs_urd_quarter_nbr as qrt_n
,hlfs_urd_fam_num_dep_nbr
,hlfs_urd_fam_num_indep_nbr
,hlfs_urd_fam_with_partner_ind
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_CopDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind>0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_CopNoDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null then (case when hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_dep_nbr>0 then 1 else 0 end) else null end as FAM_SoleDep
,case when hlfs_urd_fam_with_partner_ind is not null and hlfs_urd_fam_num_dep_nbr is not null and hlfs_urd_fam_num_indep_nbr is not null then (case when (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr>0 and hlfs_urd_fam_num_dep_nbr=0) or (hlfs_urd_fam_with_partner_ind=0 and hlfs_urd_fam_num_indep_nbr=0 and hlfs_urd_fam_num_dep_nbr=0) then 1 else 0 end) else null end as FAM_Singles
,case when hlfs_urd_quarter_nbr = 142 then 4 else hlfs_urd_quarter_nbr end as hlfs_qrt
,hlfs_urd_region_code as DEM_Region_org
,case
when hlfs_urd_region_code = '01' or hlfs_urd_region_code = '04' or hlfs_urd_region_code = '05' then 1 
when hlfs_urd_region_code = '02' then 2
when hlfs_urd_region_code = '03' then 3
when hlfs_urd_region_code = '06' or hlfs_urd_region_code = '07' then 4
when hlfs_urd_region_code = '08' then 5
when hlfs_urd_region_code = '09' then 6
when hlfs_urd_region_code = '10' then 7
when hlfs_urd_region_code = '11' or hlfs_urd_region_code = '12' then 8 
else null end as DEM_Region_8 
,case
when  hlfs_urd_lfs_code= 1 then 1
when  hlfs_urd_lfs_code= 2 then 0
when  hlfs_urd_lfs_code= 3 then 0
when  hlfs_urd_lfs_code = 9 then null
else NULL end as EST_Emp1
,hlfs_urd_age_nbr as DEM_Age
from IDI_Clean_202206.hlfs_clean.data ) as hl1
on sup.hl_idsup = hl1.hlfs_id
and sup.hl_hhidsup = hl1.hh_id
and sup.personID = hl1.p_id
and sup.qrt_num = hl1.qrt_n;

--verify data:
select * from #hlfs4

-- Step 2
create table #hlfs4b
(
snz_uid	int
,hh_id	int
, gss_id int
,hlfs_id	int
,hlfs_qrt	int
,interview_date	date
,survey_yr	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,DEM_Region_org int
,DEM_Region_8 int
,EST_Emp1 int
)
insert into #hlfs4b
select 
snz_uid	
,hh_id	
, gss_id 
,hlfs_id	
,hlfs_qrt	
,interview_date	
,survey_yr	
,personID	
,DEM_Gend	
,DEM_Age	
,DEM_birth_month	
,DEM_birth_year	
,DEM_Euro	
,DEM_Maori	
,DEM_Pacific	
,DEM_Asian	
,DEM_MELAA	
,DEM_Other	
,DEM_Disabled	
,DEM_Migrant	
,SW_Identity	
,SW_LifeSat	
,SW_FamWell	
,HLT_GenHlth	
,HLT_MenHlth1	
,HLT_MenHlth2	
,HLT_MenHlth3	
,SFT_Safe	
,SFT_Victim	
,EST_MatWell1	
,EST_MatWell2	
,EST_MatWell3	
,EST_EnoughMon	
,HOU_Damp	
,HOU_Cold	
,HOU_Crowded	
,SC_Trust_police	
,SC_Trust_parl	
,SC_Trust_health	
,SC_Trust_media	
,SC_Discrim	
,SC_Support	
,SC_ConFam	
,SC_ConFrd	
,SC_Lonely	
,FAM_CopDep as FAM_CopDep
,FAM_CopNoDep as FAM_CopNoDep
,FAM_SoleDep as FAM_SoleDep
,FAM_Singles as FAM_Singles
,DEM_Region_org
,DEM_Region_8
,EST_Emp1
from #hlfs4




-- UNION OF ALL FOUR QUARTERLY TABLES
-- save it into a temporary table #hlfs_all

create table #hlfs_all
(
snz_uid	int
,hh_id	int
, gss_id int
,hlfs_id	int
,hlfs_qrt	int
,interview_date	date
,survey_yr	int
,personID	int
,DEM_Gend	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2	int
,HLT_MenHlth3	int
,SFT_Safe	int
,SFT_Victim	int
,EST_MatWell1	int
,EST_MatWell2	int
,EST_MatWell3	int
,EST_EnoughMon	int
,EST_Emp1 int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support	int
,SC_ConFam	int
,SC_ConFrd	int
,SC_Lonely	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
,DEM_Region_org int
,DEM_Region_8 int
)
insert into #hlfs_all
select * from #hlfs1b
union 
select * from #hlfs2b
union
select * from #hlfs3b
union
select * from #hlfs4b

--verify data:
select * from #hlfs_all



--JOIN GSS AND HLFS 

--tidy up survey years
-- save data into a temporary table: #gss_hlfs
select * ,
case when survey_yr = 2008 then 2008 
when survey_yr = 2009 then 2008 
when survey_yr = 2010 then 2010
when survey_yr = 2011 then 2010
when survey_yr = 2012 then 2012
when survey_yr = 2013 then 2012
when survey_yr = 2014 then 2014
when survey_yr = 2015 then 2014
when survey_yr = 2016 then 2016
when survey_yr = 2017 then 2016
when survey_yr = 2018 then 2018
when survey_yr = 2019 then 2018
when survey_yr = 2020 then 2020
when survey_yr = 2021 then 2020 else null end as survey_year
into #gss_hlfs
from  #gss_all_temp
union 
select * ,
case when survey_yr = 2008 then 2008 
when survey_yr = 2009 then 2008 
when survey_yr = 2010 then 2010
when survey_yr = 2011 then 2010
when survey_yr = 2012 then 2012
when survey_yr = 2013 then 2012
when survey_yr = 2014 then 2014
when survey_yr = 2015 then 2014
when survey_yr = 2016 then 2016
when survey_yr = 2017 then 2016
when survey_yr = 2018 then 2018
when survey_yr = 2019 then 2018
when survey_yr = 2020 then 2020
when survey_yr = 2021 then 2020 else null end as survey_year
from #hlfs_all

-- drop old survey year variable
alter table #gss_hlfs
drop column survey_yr




--verify data
select * from #gss_hlfs
order by 
survey_year desc,
hlfs_qrt desc,
hh_id asc;


/*
-- detect duplicates based on snz_uid 
-- most of these are people who were interviewed at each quarter of the hlfs
-- this has no importance because most wellbeing variables are derived from one quarter
-- of course there are some people who were included in both gss and hlfs 
-- this will create dependency issues across waves, so we decided to delete all person level duplicates


select snz_uid
,cnt
--into #dup_snz
from (
select snz_uid
,count(snz_uid) as cnt
from #gss_hlfs
group by
snz_uid
) start0
order by cnt desc


-- check some of these
select * from #gss_hlfs
where snz_uid = *****
or snz_uid = *****
or snz_uid = *****
or snz_uid = *****
or snz_uid = *****
or snz_uid = *****
or snz_uid = *****
or snz_uid = *****
order by hh_id, hlfs_qrt, snz_uid;



-- detect duplicates based on hh_id 
-- these are mainly different people from the same household who were interviewed at different timepoints. 
-- this is okay

select 
hh_id
,cnthh
from (
select 
hh_id
,count(hh_id) as cnthh
from #gss_hlfs
group by
hh_id) start0
order by  
cnthh desc


-- check some of these
select * from #gss_hlfs
where hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
order by hh_id, hlfs_qrt;

*/


-- DELETE duplicates based on snz_uid (to avoid dependency across waves)
with cte as(
select *,
row_number() over (
partition by
snz_uid
order by snz_uid
) row_num
from #gss_hlfs
) delete from cte
where row_num >1;


/*
-- now check duplicates in household  again

select 
hh_id
,cnthh
from (
select 
hh_id
,count(hh_id) as cnthh
from #gss_hlfs
group by
hh_id) start0
order by  
cnthh desc
,hh_id desc;



-- check some of these
select * from #gss_hlfs
where hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
or hh_id = *****
order by hh_id, hlfs_qrt;
*/

--verify data
select * from #gss_hlfs
order by 
survey_year asc,
hlfs_qrt asc,
hh_id asc;



------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------
-- Finally, select everything from the temporary table and save it to Sandpit
-- After runnning the code below, we can open any statistical programme and pull this newly created table from Sandpit


  CREATE TABLE IDI_Sandpit.[DL-MAA2019-70].[for_ben]   (
snz_uid	int
,hh_id	int
,gss_id	int
,hlfs_id	int
,hlfs_qrt	int
,interview_date	date
,survey_year	int
,personID	int
,DEM_Gend 	int
,DEM_Age	int
,DEM_birth_month	int
,DEM_birth_year	int
,DEM_Euro	int
,DEM_Maori	int
,DEM_Pacific	int
,DEM_Asian	int
,DEM_MELAA	int
,DEM_Other	int
,DEM_Region_org int
,DEM_Region_8 int
,DEM_Disabled	int
,DEM_Migrant	int
,SW_Identity	int
,SW_LifeSat	int
,SW_FamWell	int
,HLT_GenHlth	int
,HLT_MenHlth1	int
,HLT_MenHlth2 	int
,HLT_MenHlth3 	int
,HLT_MenHlth dec
,SFT_Safe	int
,SFT_Victim 	int
,EST_MatWell1	int
,EST_MatWell2 	int
,EST_MatWell3	int
,EST_MatWell_Def float
,EST_EnoughMon	int
,EST_Emp1 int
,HOU_Damp	int
,HOU_Cold	int
,HOU_Crowded	int
,SC_Trust_police	int
,SC_Trust_parl	int
,SC_Trust_health	int
,SC_Trust_media	int
,SC_Discrim	int
,SC_Support 	int
,SC_ConFam   	int
,SC_ConFrd   	int
,SC_Lonely 	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int 
,FAM_Singles int
)
insert into IDI_Sandpit.[DL-MAA2019-70].[for_ben] (
snz_uid
,hh_id	
,gss_id
,hlfs_id
,hlfs_qrt
,interview_date	
,survey_year
,personID
,DEM_Gend 
,DEM_Age
,DEM_birth_month
,DEM_birth_year
,DEM_Euro
,DEM_Maori
,DEM_Pacific
,DEM_Asian
,DEM_MELAA
,DEM_Other
,DEM_Region_org
,DEM_Region_8
,DEM_Disabled
,DEM_Migrant
,SW_Identity
,SW_LifeSat
,SW_FamWell
,HLT_GenHlth
,HLT_MenHlth1
,HLT_MenHlth2
,HLT_MenHlth3
,HLT_MenHlth
,SFT_Safe
,SFT_Victim 
,EST_MatWell1
,EST_MatWell2 
,EST_MatWell3
,EST_MatWell_Def
,EST_EnoughMon
,EST_Emp1
,HOU_Damp
,HOU_Cold
,HOU_Crowded
,SC_Trust_police
,SC_Trust_parl
,SC_Trust_health
,SC_Trust_media
,SC_Discrim
,SC_Support 
,SC_ConFam   
,SC_ConFrd   
,SC_Lonely 
,FAM_CopDep 
,FAM_CopNoDep 
,FAM_SoleDep  
,FAM_Singles 
)
select
snz_uid
,hh_id	
,gss_id
,hlfs_id
,hlfs_qrt
,interview_date	
,survey_year
,personID
,DEM_Gend 
,DEM_Age
,DEM_birth_month
,DEM_birth_year
,DEM_Euro
,DEM_Maori
,DEM_Pacific
,DEM_Asian
,DEM_MELAA
,DEM_Other
,DEM_Region_org 
,DEM_Region_8 
,DEM_Disabled
,DEM_Migrant
,SW_Identity
,SW_LifeSat
,SW_FamWell
,HLT_GenHlth
,HLT_MenHlth1
,HLT_MenHlth2
,HLT_MenHlth3
-- create sum of mental health items
-- this is highly problematic across waves, I recommend not using it
-- (I tried different ways of harmonizing it across waves, this is the best I could think of (see above in code), here I just sum the items, but this is not a reliable way of measuring this indicator across years)
,case when HLT_MenHlth1 is not null and HLT_MenHlth2 is not null and HLT_MenHlth3 is not null then (HLT_MenHlth1 + HLT_MenHlth2 + HLT_MenHlth3) else null end as HLT_MenHlth
,SFT_Safe
,SFT_Victim 
,EST_MatWell1
,EST_MatWell2 
,EST_MatWell3
--create a deflated material wellbeing variable which we can use to compare this indicator across waves
--Note: we checked these variables and deflation only works for EST_MatWell1. EST_MatWell3 is different and cannot be used here
, case when EST_MatWell2 is not null then EST_MatWell2 else EST_MatWell1*0.6451612903 end as MatWell_Def 
,EST_EnoughMon
,EST_Emp1
,HOU_Damp
,HOU_Cold
,HOU_Crowded
,SC_Trust_police
,SC_Trust_parl
,SC_Trust_health
,SC_Trust_media
,SC_Discrim
,SC_Support 
,SC_ConFam   
,SC_ConFrd   
,SC_Lonely 
,FAM_CopDep 
,FAM_CopNoDep 
,FAM_SoleDep  
,FAM_Singles 
FROM #gss_hlfs as alldata
order by survey_year,
hlfs_qrt,
hh_id
;


-- Clean up all the mess and delete tables that we do not need
/*
drop table #hlfs1
drop table #hlfs1b
drop table #hlfs2
drop table #hlfs2b
drop table #hlfs3
drop table #hlfs3b
drop table #hlfs4
drop table #hlfs4b
drop table #hlfs_all
drop table #gss_hlfs
drop table #gss_all_temp
--drop table IDI_Sandpit.[DL-MAA2019-70].[for_ben]
*/

select * from IDI_Sandpit.[DL-MAA2019-70].[for_ben]





-----------------------------------------------------------------------------------------------------------
-----------------------------------------------------------------------------------------------------------
-----------------------------------------------------------------------------------------------------------
----------------------------             MAIN BENEFIT				---------------------------------------
-----------------------------------------------------------------------------------------------------------
-----------------------------------------------------------------------------------------------------------
-----------------------------------------------------------------------------------------------------------


-- here I join the main benefit table based on certain restrictions
-- I use temporary tables to gradually work through the data creation process


SELECT 
temp. *
,msd_fte_period_nbr 
,msd_fte_srvst_code as ben_type
,msd_fte_start_date 
,msd_fte_end_date
--next lines creates a framework for benefit periods (e.g., start=if benefit started earlier than 3 years prior interview date then start=three years before inerview date)
--(end=if benefit ended after interview data OR is current (i.e., null) then end=interview date
--this creates start and end dates that are limited from 3 years/1year/1month before interview date and up to interview date
--we need this to create a variable that is the total days on benefit within these specified timeframes (this comes later)
,case when msd_fte_start_date < DATEADD(month, -36, interview_date) then DATEADD(month, -36, interview_date) else msd_fte_start_date end as ben_start36
,case when msd_fte_start_date < DATEADD(month, -12, interview_date) then DATEADD(month, -12, interview_date) else msd_fte_start_date end as ben_start12
,case when msd_fte_start_date < DATEADD(month, -1, interview_date) then DATEADD(month, -1, interview_date) else msd_fte_start_date end as ben_start01
,case when msd_fte_end_date > interview_date or msd_fte_end_date is NULL then interview_date else msd_fte_end_date end as ben_end_date
-- here I create variables that tell us whether a row of benefit status is relevant to us (based on whether the benefit was winthin the 3 year/1year/1month timeframe of their survey year)
-- note: this only shows whether someone had benefit in the last 3 years/1year/1month or not 
-- it does not tell us when exactly they had benefit and how how long they had it for 
-- we need this later to aggregate the total number of days on benefit by each of these periods 
,case when  msd_fte_end_date < DATEADD(month, -36, interview_date)  or msd_fte_period_nbr is null or msd_fte_start_date >interview_date  then 0 else 1 end as ben36
, case when msd_fte_end_date < DATEADD(month, -12, interview_date) or msd_fte_period_nbr is null or msd_fte_start_date >interview_date  then 0 else 1 end as ben12
, case when msd_fte_end_date < DATEADD(month, -1, interview_date) or msd_fte_period_nbr is null or msd_fte_start_date >interview_date  then 0 else 1 end as ben01
into #ben
FROM IDI_Sandpit.[DL-MAA2019-70].[for_ben] as temp left join IDI_Clean_202206.msd_clean.msd_first_tier_expenditure as ben
ON temp.snz_uid = ben.snz_uid
ORDER BY survey_year asc,
hlfs_qrt asc,
hh_id asc
;



--verify action
select top(1000) * from #ben
order by hh_id



-- this is not an aggregated table - use this to error check the aggregated table that I create later (#ben3)
select 
*
--this sums up the total number of days on benefit within 3years/1year/1month
--if the person had benefit but it is not within the above specified timeframe, then the number of days is meaningless (stored as a minus number)
--one person appears in multiple rows because they had multiple benefit spells
,DATEDIFF(day, ben_start36, ben_end_date)+1 as ben_tot36
,DATEDIFF(day, ben_start12, ben_end_date)+1 as ben_tot12
,DATEDIFF(day, ben_start01, ben_end_date)+1 as ben_tot01
--,case when ben36 = 0 then null else msd_fte_start_date end as ben_start
--,case when ben36 = 0 then null else msd_fte_end_date end as ben_end
into #ben_not_agg
from #ben
ORDER BY 
hh_id asc,
msd_fte_start_date asc
;

/*
--to error check the benefit periods within timeframes
select top(1000) 
snz_uid
,   interview_date
,	msd_fte_period_nbr
,	ben_type
,	msd_fte_start_date
,	msd_fte_end_date
,	ben_start36
,	ben_start12
,	ben_start01
,	ben_end_date
,	ben36
,	ben12
,	ben01
,	ben_tot36
,	ben_tot12
,	ben_tot01
--,	ben_start
--,	ben_end
from #ben_not_agg
order by snz_uid , msd_fte_start_date
*/

-- next I will do aggregations in two steps:

-- first, this aggregates the data by the sum of total benefit received within the three specified timeframes
-- note it creates duplicates which needs to be fixed (second aggregation)
select
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
,	ben36
,	ben12
,	ben01
--this tells us the number of days on benefit within the last 3year/1year/1month
,case when  ben36 = 1 then sum(ben_tot36) end as sum_ben36
,case when  ben12 = 1 then sum(ben_tot12) end as sum_ben12
,case when  ben01 = 1 then sum(ben_tot01) end as sum_ben01
into #ben2
from #ben_not_agg
group by 
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
,	ben36
,	ben12
,	ben01
order by  hh_id;

--verify action

select top(1000)
snz_uid
,   interview_date
,	ben36
,	ben12
,	ben01
,	sum_ben36
,	sum_ben12
,	sum_ben01
from #ben2
order by survey_year,  hh_id




-- second aggregation, final table:
-- here I use the number of days on benefit within each period to create three binary variables:
-- ben_30: 0=no, 1=yes, the person was on benefit for 30+ months (=approx 900 days) in the last 3 years
-- ben_12: 0=no, 1=yes, the person was on benefit for at least 1 day in the last 1 year
-- ben_01: 0=no, 1=yes, the person was on benefit for at least 1 day in the last 1 month
select 
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
,sum(sum_ben36) as sum_ben36
,sum(sum_ben12) as sum_ben12
,sum(sum_ben01) as sum_ben01
,case when sum(sum_ben36) > 900 then 1 else 0 end as ben_30
,case when sum(sum_ben12) >=1 then 1 else 0 end as ben_12
,case when sum(sum_ben01) >=1 then 1 else 0 end as ben_01
into #ben3
from #ben2
group by 
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
order by 
survey_year,
hh_id


-- verify action
select * from #ben3
order by survey_year,  hh_id


/*
-- here we do some error checking
-- all the maximum benefit days should be within the 3-year, 1-year and 1-month benefit periods
--however, only the 3-year period is relavant, because anyone who had benefit for a day will be in the 1-year and 1-month periods

select 
max(sum_ben36) as max30
, max(sum_ben12) as max12
, max(sum_ben01) as max01
from #ben3


--there are a few people who had benefit for more than 3 years, which is only possible if there are duplicates in benefit periods 

select 
snz_uid,
sum_ben36
from #ben3
order by sum_ben36 desc

-- I use Excel to manually and randomly check these cases:
-- I randomly select 20 people whose benefit period is longer than 3 years 
-- NOTE, I use benefit tables before aggregation to check these periods 
-- I manually check whether the number of benefit days is still more than 30 months for those who received benefit for 3 years after deleting the duplicate benefit periods 
-- to do this check: I select the #ben_not_agg table and the #ben3 table, copy-paste the relevant info to an Excel file and compare the raw benefit spells to max30, max12 and max01
-- to see whether the number of days on benefit per period will still fall into the specified timeframe when ignoring the benefit spells that overlap within person. 

-- verify action
select  * from #ben_not_agg
--where snz_uid = *****
order by  hh_id,
msd_fte_start_date asc
;

select snz_uid, hh_id, interview_date, msd_fte_period_nbr, msd_fte_start_date, msd_fte_end_date, ben36 from #ben
where 
snz_uid	= ***** -- INTERVIEW DATE IS MISSING, NUMBERS ARE WRONG 
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= ***** --ok
or	snz_uid	= ***** --msd data are weird but our calculation is ok
or	snz_uid	= *****
or	snz_uid	= ***** --ok
or	snz_uid	= ***** --ok
or	snz_uid	= ***** --msd data are weird but our calculation is ok
or	snz_uid	= ***** --ok
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= ***** --ok
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****  --ok
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= *****  --ok
or	snz_uid	= *****
or	snz_uid	= ***** --ok
or	snz_uid	= *****
or	snz_uid	= ***** --ok
or	snz_uid	= ***** -- INTERVIEW DATE IS MISSING, NUMBERS ARE WRONG	(from 2012)
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= ***** --ok
or	snz_uid	= ***** --ok
or	snz_uid	= *****
or	snz_uid	= *****
or	snz_uid	= ***** --ok
or	snz_uid	= ***** --ok
or	snz_uid	= ***** --ok
or	snz_uid	= ***** --ok
or	snz_uid	= *****
or	snz_uid	= ***** --ok
order by 
snz_uid,
msd_fte_start_date;
*/




-- it turns out that there are a few people who have no interview dates, hence, benefit periods are misleading
-- I checked them all, I drop these people because we cannot calculate benenfit days if interview date is missing (or imputed) 

select * from #ben3
where
interview_date is null and ben_30 = 1 or interview_date is null and ben_12 = 1 or interview_date is null and ben_01 = 1 



-- !!!!!!!!!delete people without interview dates (n=****)
delete from #ben3 
where
interview_date is null and ben_30 = 1 or interview_date is null and ben_12 = 1 or interview_date is null and ben_01 = 1 



/*
select * from #ben3

-- to detect duplicates based on snz_uid (NO duplicates)
select 
snz_uid
,cnthh
from (
select 
snz_uid
,count(snz_uid) as cnthh
from #ben3
group by
snz_uid) start0
order by  
cnthh desc;

*/

--save created table into Sandpit 
create table IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd1] (
	snz_uid	int
,	hh_id	int
,	gss_id	int
,	hlfs_id	int
,	hlfs_qrt	int
,	interview_date	date
,	survey_year	int
,	personID	int
,	DEM_Gend	int
,	DEM_Age	int
,	DEM_birth_month	int
,	DEM_birth_year	int
,	DEM_Euro	int
,	DEM_Maori	int
,	DEM_Pacific	int
,	DEM_Asian	int
,	DEM_MELAA	int
,	DEM_Other	int
,	DEM_Region_org	int
,	DEM_Region_8	int
,	DEM_Disabled	int
,	DEM_Migrant	int
,	SW_Identity	int
,	SW_LifeSat	int
,	SW_FamWell	int
,	HLT_GenHlth	int
,	HLT_MenHlth1	int
,	HLT_MenHlth2	int
,	HLT_MenHlth3	int
,	HLT_MenHlth	float
,	SFT_Safe	int
,	SFT_Victim	int
,	EST_MatWell1	int
,	EST_MatWell2	int
,	EST_MatWell3	int
,	EST_MatWell_Def	int
,	EST_EnoughMon	int
,	EST_Emp1 int
,	HOU_Damp	int
,	HOU_Cold	int
,	HOU_Crowded	int
,	SC_Trust_police	int
,	SC_Trust_parl	int
,	SC_Trust_health	int
,	SC_Trust_media	int
,	SC_Discrim	int
,	SC_Support	int
,	SC_ConFam	int
,	SC_ConFrd	int
,	SC_Lonely	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int
,FAM_Singles int
,FAM_FamStr int
,	sum_ben36	int
,	sum_ben12	int
,	sum_ben01	int
,	main_ben_30	int
,	main_ben_12	int
,	main_ben_01	int
,   main_ben_no int
)
insert into IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd1] 
(
	snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,	HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
,FAM_FamStr
,	sum_ben36
,	sum_ben12
,	sum_ben01
,	main_ben_30
,	main_ben_12
,	main_ben_01
,   main_ben_no
)
select 
	snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,	HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
, case when FAM_CopDep = 1 then 1 when  FAM_CopNoDep =1 then 2 when FAM_SoleDep = 1 then 3 when FAM_Singles = 1 then 4 else null end as FAM_FamStr -- create nominal family structure variable 
,	sum_ben36
,	sum_ben12
,	sum_ben01
,	ben_30 as main_ben_30
,	ben_12 as main_ben_12
,	ben_01 as main_ben01
,   case when ben_30 = 0 and ben_12 = 0 and ben_01 = 0 then 1 else 0 end as main_ben_no -- 1 = no benefit at all in the last 30 months, 0 = some benefit in the last 30 months  
FROM #ben3
order by survey_year,
hlfs_qrt,
hh_id
;
 
 --verify action n = *****
  select * from IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd1] 
 order by survey_year,
hlfs_qrt,
hh_id
;


/*
-- Clean up the mess and delete tables that we do not need

drop table #hlfs1
drop table #hlfs1b
drop table #hlfs2
drop table #hlfs2b
drop table #hlfs3
drop table #hlfs3b
drop table #hlfs4
drop table #hlfs4b
drop table #hlfs_all
drop table #gss_all_temp
drop table #gss_hlfs
drop table #ben_not_agg
drop table #ben
drop table #ben2
drop table #ben3
--drop table IDI_Sandpit.[DL-MAA2019-70].[for_ben]
--drop table IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd1]
*/





---------------------------------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------------------------------
------------------------------    Create second tier data      ------------------------------------------------
---------------------------------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------------------------------




-- here I join the MSD benefit table (second_tier) based on the same restrictions:
-- only difference here is that we use the msd second tier table (rather than first-tier) to join benefit data to our cleaned gss_hlfs data


SELECT 
temp. *
,msd_ste_period_nbr 
,msd_ste_srvst_code as ben_type
,msd_ste_start_date 
,msd_ste_end_date
,case when msd_ste_start_date < DATEADD(month, -36, interview_date) then DATEADD(month, -36, interview_date) else msd_ste_start_date end as ben_start36
,case when msd_ste_start_date < DATEADD(month, -12, interview_date) then DATEADD(month, -12, interview_date) else msd_ste_start_date end as ben_start12
,case when msd_ste_start_date < DATEADD(month, -1, interview_date) then DATEADD(month, -1, interview_date) else msd_ste_start_date end as ben_start01
,case when msd_ste_end_date > interview_date or msd_ste_end_date is NULL then interview_date else msd_ste_end_date end as ben_end_date
,case when  msd_ste_end_date < DATEADD(month, -36, interview_date)  or msd_ste_period_nbr is null or msd_ste_start_date >interview_date  then 0 else 1 end as ben36
, case when msd_ste_end_date < DATEADD(month, -12, interview_date) or msd_ste_period_nbr is null or msd_ste_start_date >interview_date  then 0 else 1 end as ben12
, case when msd_ste_end_date < DATEADD(month, -1, interview_date) or msd_ste_period_nbr is null or msd_ste_start_date >interview_date  then 0 else 1 end as ben01
into #ben_sec
FROM IDI_Sandpit.[DL-MAA2019-70].[for_ben] as temp left join IDI_Clean_202206.msd_clean.msd_second_tier_expenditure as ben
ON temp.snz_uid = ben.snz_uid
ORDER BY survey_year asc,
hlfs_qrt asc,
hh_id asc
;



--verify action
select top(1000) * from #ben_sec
order by hh_id



-- this is not an aggregated table - use this to error check the aggregated table that I create later (#ben3)
select 
*
,DATEDIFF(day, ben_start36, ben_end_date)+1 as ben_tot36
,DATEDIFF(day, ben_start12, ben_end_date)+1 as ben_tot12
,DATEDIFF(day, ben_start01, ben_end_date)+1 as ben_tot01

into #ben_not_agg_sec
from #ben_sec
ORDER BY 
hh_id asc,
msd_ste_start_date asc
;

/*
--to error check the benefit periods within timeframes
select top(1000) 
snz_uid
,   interview_date
,	msd_ste_period_nbr
,	ben_type
,	msd_ste_start_date
,	msd_ste_end_date
,	ben_start36
,	ben_start12
,	ben_start01
,	ben_end_date
,	ben36
,	ben12
,	ben01
,	ben_tot36
,	ben_tot12
,	ben_tot01
--,	ben_start
--,	ben_end
from #ben_not_agg_sec
order by snz_uid , msd_ste_start_date
*/



-- aggregate the data by the sum of total benefit received within the three specified timeframes
select
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
,	ben36
,	ben12
,	ben01
--this tells us the number of days on benefit within the last 3year/1year/1month
,case when  ben36 = 1 then sum(ben_tot36) end as sum_ben36
,case when  ben12 = 1 then sum(ben_tot12) end as sum_ben12
,case when  ben01 = 1 then sum(ben_tot01) end as sum_ben01
into #ben2_sec
from #ben_not_agg_sec
group by 
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
,	ben36
,	ben12
,	ben01
order by  hh_id;

--verify action

select top(1000)
snz_uid
,   interview_date
,	ben36
,	ben12
,	ben01
,	sum_ben36
,	sum_ben12
,	sum_ben01
from #ben2_sec
order by survey_year,  hh_id




-- second aggregation, final table:
-- here I use the number of days on benefit within each period to create three binary variables:
-- ben_30: 0=no, 1=yes, the person was on benefit for 30+ months (=approx 900 days) in the last 3 years
-- ben_12: 0=no, 1=yes, the person was on benefit for at least 1 day in the last 1 year
-- ben_01: 0=no, 1=yes, the person was on benefit for at least 1 day in the last 1 month
select 
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
,sum(sum_ben36) as sum_ben36
,sum(sum_ben12) as sum_ben12
,sum(sum_ben01) as sum_ben01
,case when sum(sum_ben36) > 900 then 1 else 0 end as ben_30
,case when sum(sum_ben12) >=1 then 1 else 0 end as ben_12
,case when sum(sum_ben01) >=1 then 1 else 0 end as ben_01
into #ben3_sec
from #ben2_sec
group by 
snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,   HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,   FAM_CopDep 
,   FAM_CopNoDep 
,   FAM_SoleDep  
,   FAM_Singles 
order by 
survey_year,
hh_id


-- verify action
select * from #ben3_sec
order by survey_year,  hh_id



/*
-- error checking
-- all the maximum benefit days should be withing the 3-year, 1-year and 1-month benefit periods
--however, only the 3-year period is relavant, because anyone who had benefit for a day will be in the 1-year and 1-month periods

select 
max(sum_ben36) as max30
, max(sum_ben12) as max12
, max(sum_ben01) as max01
from #ben3_sec

--there are a few people who had benefit for more than 3 years, which is only possible if there are duplicates in benefit periods 
select 
snz_uid,
sum_ben36
from #ben3_sec
order by sum_ben36 desc

-- I randomly checked 20 people with super long benefit periods in the main benefit data, not in this data. 
-- Based on the previous error check, we know that there are a few people without interview dates. 
-- We delete them here as well

-- !!!!!!!!!!!!!!delete people without interview dates (n=*****)
select * from #ben3_sec
where
interview_date is null and ben_30 = 1 or interview_date is null and ben_12 = 1 or interview_date is null and ben_01 = 1 
*/


delete from #ben3_sec 
where
interview_date is null and ben_30 = 1 or interview_date is null and ben_12 = 1 or interview_date is null and ben_01 = 1 



select * from #ben3_sec


/*
-- to detect duplicates based on snz_uid (NO duplicates)
select 
snz_uid
,cnthh
from (
select 
snz_uid
,count(snz_uid) as cnthh
from #ben3_sec
group by
snz_uid) start0
order by  
cnthh desc;


--save our created table into Sandpit 


*/


create table IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd2] (
	snz_uid	int
,	hh_id	int
,	gss_id	int
,	hlfs_id	int
,	hlfs_qrt	int
,	interview_date	date
,	survey_year	int
,	personID	int
,	DEM_Gend	int
,	DEM_Age	int
,	DEM_birth_month	int
,	DEM_birth_year	int
,	DEM_Euro	int
,	DEM_Maori	int
,	DEM_Pacific	int
,	DEM_Asian	int
,	DEM_MELAA	int
,	DEM_Other	int
,	DEM_Region_org	int
,	DEM_Region_8	int
,	DEM_Disabled	int
,	DEM_Migrant	int
,	SW_Identity	int
,	SW_LifeSat	int
,	SW_FamWell	int
,	HLT_GenHlth	int
,	HLT_MenHlth1	int
,	HLT_MenHlth2	int
,	HLT_MenHlth3	int
,	HLT_MenHlth	float
,	SFT_Safe	int
,	SFT_Victim	int
,	EST_MatWell1	int
,	EST_MatWell2	int
,	EST_MatWell3	int
,	EST_MatWell_Def	int
,	EST_EnoughMon	int
,	EST_Emp1 int
,	HOU_Damp	int
,	HOU_Cold	int
,	HOU_Crowded	int
,	SC_Trust_police	int
,	SC_Trust_parl	int
,	SC_Trust_health	int
,	SC_Trust_media	int
,	SC_Discrim	int
,	SC_Support	int
,	SC_ConFam	int
,	SC_ConFrd	int
,	SC_Lonely	int
,FAM_CopDep int
,FAM_CopNoDep int
,FAM_SoleDep int
,FAM_Singles int
,FAM_FamStr int
,	sum_ben36	int
,	sum_ben12	int
,	sum_ben01	int
,	msd_ben_30	int
,	msd_ben_12	int
,	msd_ben_01	int
,   msd_ben_no int
)
insert into IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd2] 
(
	snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,	HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
,FAM_FamStr
,	sum_ben36
,	sum_ben12
,	sum_ben01
,	msd_ben_30
,	msd_ben_12
,	msd_ben_01
,  msd_ben_no
)
select 
	snz_uid
,	hh_id
,	gss_id
,	hlfs_id
,	hlfs_qrt
,	interview_date
,	survey_year
,	personID
,	DEM_Gend
,	DEM_Age
,	DEM_birth_month
,	DEM_birth_year
,	DEM_Euro
,	DEM_Maori
,	DEM_Pacific
,	DEM_Asian
,	DEM_MELAA
,	DEM_Other
,   DEM_Region_org
,   DEM_Region_8
,	DEM_Disabled
,	DEM_Migrant
,	SW_Identity
,	SW_LifeSat
,	SW_FamWell
,	HLT_GenHlth
,	HLT_MenHlth1
,	HLT_MenHlth2
,	HLT_MenHlth3
,	HLT_MenHlth
,	SFT_Safe
,	SFT_Victim
,	EST_MatWell1
,	EST_MatWell2
,	EST_MatWell3
,   EST_MatWell_Def
,	EST_EnoughMon
,	EST_Emp1
,	HOU_Damp
,	HOU_Cold
,	HOU_Crowded
,	SC_Trust_police
,	SC_Trust_parl
,	SC_Trust_health
,	SC_Trust_media
,	SC_Discrim
,	SC_Support
,	SC_ConFam
,	SC_ConFrd
,	SC_Lonely
,FAM_CopDep
,FAM_CopNoDep
,FAM_SoleDep
,FAM_Singles
, case when FAM_CopDep = 1 then 1 when  FAM_CopNoDep =1 then 2 when FAM_SoleDep = 1 then 3 when FAM_Singles = 1 then 4 else null end as FAM_FamStr -- create nominal family structure variable 
,	sum_ben36
,	sum_ben12
,	sum_ben01
,	ben_30 as msd_ben_30
,	ben_12 as msd_ben_12
,	ben_01 as msd_ben_01
,   case when ben_30 = 0 and ben_12 = 0 and ben_01 = 0 then 1 else 0 end as msd_ben_no -- 1 = no benefit at all in the last 3o months, 0 = some benefit in the last 30 months  
FROM #ben3_sec
order by survey_year,
hlfs_qrt,
hh_id
;
 
 --verify action n = *****
  select * from IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd1] 
 order by survey_year,
hlfs_qrt,
hh_id
;


  select * from IDI_Sandpit.[DL-MAA2019-70].[gss_hlfs_msd2] 
 order by survey_year,
hlfs_qrt,
hh_id
;

